/****************************************************************************
** Meta object code from reading C++ file 'fcitxqtinputcontextproxyimpl.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../fcitxqtinputcontextproxyimpl.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fcitxqtinputcontextproxyimpl.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_fcitx__FcitxQtInputContextProxyImpl_t {
    QByteArrayData data[64];
    char stringdata0[772];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_fcitx__FcitxQtInputContextProxyImpl_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_fcitx__FcitxQtInputContextProxyImpl_t qt_meta_stringdata_fcitx__FcitxQtInputContextProxyImpl = {
    {
QT_MOC_LITERAL(0, 0, 35), // "fcitx::FcitxQtInputContextPro..."
QT_MOC_LITERAL(1, 36, 12), // "CommitString"
QT_MOC_LITERAL(2, 49, 0), // ""
QT_MOC_LITERAL(3, 50, 3), // "str"
QT_MOC_LITERAL(4, 54, 9), // "CurrentIM"
QT_MOC_LITERAL(5, 64, 4), // "name"
QT_MOC_LITERAL(6, 69, 10), // "uniqueName"
QT_MOC_LITERAL(7, 80, 8), // "langCode"
QT_MOC_LITERAL(8, 89, 21), // "DeleteSurroundingText"
QT_MOC_LITERAL(9, 111, 6), // "offset"
QT_MOC_LITERAL(10, 118, 5), // "nchar"
QT_MOC_LITERAL(11, 124, 10), // "ForwardKey"
QT_MOC_LITERAL(12, 135, 6), // "keyval"
QT_MOC_LITERAL(13, 142, 5), // "state"
QT_MOC_LITERAL(14, 148, 4), // "type"
QT_MOC_LITERAL(15, 153, 14), // "NotifyFocusOut"
QT_MOC_LITERAL(16, 168, 18), // "UpdateClientSideUI"
QT_MOC_LITERAL(17, 187, 27), // "FcitxQtFormattedPreeditList"
QT_MOC_LITERAL(18, 215, 7), // "preedit"
QT_MOC_LITERAL(19, 223, 9), // "cursorpos"
QT_MOC_LITERAL(20, 233, 5), // "auxUp"
QT_MOC_LITERAL(21, 239, 7), // "auxDown"
QT_MOC_LITERAL(22, 247, 25), // "FcitxQtStringKeyValueList"
QT_MOC_LITERAL(23, 273, 10), // "candidates"
QT_MOC_LITERAL(24, 284, 14), // "candidateIndex"
QT_MOC_LITERAL(25, 299, 10), // "layoutHint"
QT_MOC_LITERAL(26, 310, 7), // "hasPrev"
QT_MOC_LITERAL(27, 318, 7), // "hasNext"
QT_MOC_LITERAL(28, 326, 22), // "UpdateFormattedPreedit"
QT_MOC_LITERAL(29, 349, 32), // "VirtualKeyboardVisibilityChanged"
QT_MOC_LITERAL(30, 382, 7), // "visible"
QT_MOC_LITERAL(31, 390, 9), // "DestroyIC"
QT_MOC_LITERAL(32, 400, 19), // "QDBusPendingReply<>"
QT_MOC_LITERAL(33, 420, 7), // "FocusIn"
QT_MOC_LITERAL(34, 428, 8), // "FocusOut"
QT_MOC_LITERAL(35, 437, 19), // "HideVirtualKeyboard"
QT_MOC_LITERAL(36, 457, 12), // "InvokeAction"
QT_MOC_LITERAL(37, 470, 6), // "action"
QT_MOC_LITERAL(38, 477, 6), // "cursor"
QT_MOC_LITERAL(39, 484, 24), // "IsVirtualKeyboardVisible"
QT_MOC_LITERAL(40, 509, 23), // "QDBusPendingReply<bool>"
QT_MOC_LITERAL(41, 533, 8), // "NextPage"
QT_MOC_LITERAL(42, 542, 8), // "PrevPage"
QT_MOC_LITERAL(43, 551, 15), // "ProcessKeyEvent"
QT_MOC_LITERAL(44, 567, 7), // "keycode"
QT_MOC_LITERAL(45, 575, 4), // "time"
QT_MOC_LITERAL(46, 580, 5), // "Reset"
QT_MOC_LITERAL(47, 586, 15), // "SelectCandidate"
QT_MOC_LITERAL(48, 602, 5), // "index"
QT_MOC_LITERAL(49, 608, 13), // "SetCapability"
QT_MOC_LITERAL(50, 622, 4), // "caps"
QT_MOC_LITERAL(51, 627, 13), // "SetCursorRect"
QT_MOC_LITERAL(52, 641, 1), // "x"
QT_MOC_LITERAL(53, 643, 1), // "y"
QT_MOC_LITERAL(54, 645, 1), // "w"
QT_MOC_LITERAL(55, 647, 1), // "h"
QT_MOC_LITERAL(56, 649, 15), // "SetCursorRectV2"
QT_MOC_LITERAL(57, 665, 5), // "scale"
QT_MOC_LITERAL(58, 671, 22), // "SetSupportedCapability"
QT_MOC_LITERAL(59, 694, 18), // "SetSurroundingText"
QT_MOC_LITERAL(60, 713, 4), // "text"
QT_MOC_LITERAL(61, 718, 6), // "anchor"
QT_MOC_LITERAL(62, 725, 26), // "SetSurroundingTextPosition"
QT_MOC_LITERAL(63, 752, 19) // "ShowVirtualKeyboard"

    },
    "fcitx::FcitxQtInputContextProxyImpl\0"
    "CommitString\0\0str\0CurrentIM\0name\0"
    "uniqueName\0langCode\0DeleteSurroundingText\0"
    "offset\0nchar\0ForwardKey\0keyval\0state\0"
    "type\0NotifyFocusOut\0UpdateClientSideUI\0"
    "FcitxQtFormattedPreeditList\0preedit\0"
    "cursorpos\0auxUp\0auxDown\0"
    "FcitxQtStringKeyValueList\0candidates\0"
    "candidateIndex\0layoutHint\0hasPrev\0"
    "hasNext\0UpdateFormattedPreedit\0"
    "VirtualKeyboardVisibilityChanged\0"
    "visible\0DestroyIC\0QDBusPendingReply<>\0"
    "FocusIn\0FocusOut\0HideVirtualKeyboard\0"
    "InvokeAction\0action\0cursor\0"
    "IsVirtualKeyboardVisible\0"
    "QDBusPendingReply<bool>\0NextPage\0"
    "PrevPage\0ProcessKeyEvent\0keycode\0time\0"
    "Reset\0SelectCandidate\0index\0SetCapability\0"
    "caps\0SetCursorRect\0x\0y\0w\0h\0SetCursorRectV2\0"
    "scale\0SetSupportedCapability\0"
    "SetSurroundingText\0text\0anchor\0"
    "SetSurroundingTextPosition\0"
    "ShowVirtualKeyboard"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_fcitx__FcitxQtInputContextProxyImpl[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      26,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  144,    2, 0x06 /* Public */,
       4,    3,  147,    2, 0x06 /* Public */,
       8,    2,  154,    2, 0x06 /* Public */,
      11,    3,  159,    2, 0x06 /* Public */,
      15,    0,  166,    2, 0x06 /* Public */,
      16,    9,  167,    2, 0x06 /* Public */,
      28,    2,  186,    2, 0x06 /* Public */,
      29,    1,  191,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      31,    0,  194,    2, 0x0a /* Public */,
      33,    0,  195,    2, 0x0a /* Public */,
      34,    0,  196,    2, 0x0a /* Public */,
      35,    0,  197,    2, 0x0a /* Public */,
      36,    2,  198,    2, 0x0a /* Public */,
      39,    0,  203,    2, 0x0a /* Public */,
      41,    0,  204,    2, 0x0a /* Public */,
      42,    0,  205,    2, 0x0a /* Public */,
      43,    5,  206,    2, 0x0a /* Public */,
      46,    0,  217,    2, 0x0a /* Public */,
      47,    1,  218,    2, 0x0a /* Public */,
      49,    1,  221,    2, 0x0a /* Public */,
      51,    4,  224,    2, 0x0a /* Public */,
      56,    5,  233,    2, 0x0a /* Public */,
      58,    1,  244,    2, 0x0a /* Public */,
      59,    3,  247,    2, 0x0a /* Public */,
      62,    2,  254,    2, 0x0a /* Public */,
      63,    0,  259,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,    5,    6,    7,
    QMetaType::Void, QMetaType::Int, QMetaType::UInt,    9,   10,
    QMetaType::Void, QMetaType::UInt, QMetaType::UInt, QMetaType::Bool,   12,   13,   14,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 17, QMetaType::Int, 0x80000000 | 17, 0x80000000 | 17, 0x80000000 | 22, QMetaType::Int, QMetaType::Int, QMetaType::Bool, QMetaType::Bool,   18,   19,   20,   21,   23,   24,   25,   26,   27,
    QMetaType::Void, 0x80000000 | 17, QMetaType::Int,    3,   19,
    QMetaType::Void, QMetaType::Bool,   30,

 // slots: parameters
    0x80000000 | 32,
    0x80000000 | 32,
    0x80000000 | 32,
    0x80000000 | 32,
    0x80000000 | 32, QMetaType::UInt, QMetaType::Int,   37,   38,
    0x80000000 | 40,
    0x80000000 | 32,
    0x80000000 | 32,
    0x80000000 | 40, QMetaType::UInt, QMetaType::UInt, QMetaType::UInt, QMetaType::Bool, QMetaType::UInt,   12,   44,   13,   14,   45,
    0x80000000 | 32,
    0x80000000 | 32, QMetaType::Int,   48,
    0x80000000 | 32, QMetaType::ULongLong,   50,
    0x80000000 | 32, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,   52,   53,   54,   55,
    0x80000000 | 32, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Double,   52,   53,   54,   55,   57,
    0x80000000 | 32, QMetaType::ULongLong,   50,
    0x80000000 | 32, QMetaType::QString, QMetaType::UInt, QMetaType::UInt,   60,   38,   61,
    0x80000000 | 32, QMetaType::UInt, QMetaType::UInt,   38,   61,
    0x80000000 | 32,

       0        // eod
};

void fcitx::FcitxQtInputContextProxyImpl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<FcitxQtInputContextProxyImpl *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->CommitString((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->CurrentIM((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 2: _t->DeleteSurroundingText((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 3: _t->ForwardKey((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 4: _t->NotifyFocusOut(); break;
        case 5: _t->UpdateClientSideUI((*reinterpret_cast< FcitxQtFormattedPreeditList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< FcitxQtFormattedPreeditList(*)>(_a[3])),(*reinterpret_cast< FcitxQtFormattedPreeditList(*)>(_a[4])),(*reinterpret_cast< FcitxQtStringKeyValueList(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7])),(*reinterpret_cast< bool(*)>(_a[8])),(*reinterpret_cast< bool(*)>(_a[9]))); break;
        case 6: _t->UpdateFormattedPreedit((*reinterpret_cast< FcitxQtFormattedPreeditList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 7: _t->VirtualKeyboardVisibilityChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: { QDBusPendingReply<> _r = _t->DestroyIC();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->FocusIn();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->FocusOut();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->HideVirtualKeyboard();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->InvokeAction((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<bool> _r = _t->IsVirtualKeyboardVisible();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<> _r = _t->NextPage();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<> _r = _t->PrevPage();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<bool> _r = _t->ProcessKeyEvent((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< uint(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->Reset();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->SelectCandidate((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->SetCapability((*reinterpret_cast< qulonglong(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<> _r = _t->SetCursorRect((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<> _r = _t->SetCursorRectV2((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< double(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->SetSupportedCapability((*reinterpret_cast< qulonglong(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<> _r = _t->SetSurroundingText((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->SetSurroundingTextPosition((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<> _r = _t->ShowVirtualKeyboard();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (FcitxQtInputContextProxyImpl::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtInputContextProxyImpl::CommitString)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (FcitxQtInputContextProxyImpl::*)(const QString & , const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtInputContextProxyImpl::CurrentIM)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (FcitxQtInputContextProxyImpl::*)(int , unsigned int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtInputContextProxyImpl::DeleteSurroundingText)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (FcitxQtInputContextProxyImpl::*)(unsigned int , unsigned int , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtInputContextProxyImpl::ForwardKey)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (FcitxQtInputContextProxyImpl::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtInputContextProxyImpl::NotifyFocusOut)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (FcitxQtInputContextProxyImpl::*)(FcitxQtFormattedPreeditList , int , FcitxQtFormattedPreeditList , FcitxQtFormattedPreeditList , FcitxQtStringKeyValueList , int , int , bool , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtInputContextProxyImpl::UpdateClientSideUI)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (FcitxQtInputContextProxyImpl::*)(FcitxQtFormattedPreeditList , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtInputContextProxyImpl::UpdateFormattedPreedit)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (FcitxQtInputContextProxyImpl::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtInputContextProxyImpl::VirtualKeyboardVisibilityChanged)) {
                *result = 7;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject fcitx::FcitxQtInputContextProxyImpl::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_meta_stringdata_fcitx__FcitxQtInputContextProxyImpl.data,
    qt_meta_data_fcitx__FcitxQtInputContextProxyImpl,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *fcitx::FcitxQtInputContextProxyImpl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::FcitxQtInputContextProxyImpl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_fcitx__FcitxQtInputContextProxyImpl.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int fcitx::FcitxQtInputContextProxyImpl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void fcitx::FcitxQtInputContextProxyImpl::CommitString(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void fcitx::FcitxQtInputContextProxyImpl::CurrentIM(const QString & _t1, const QString & _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void fcitx::FcitxQtInputContextProxyImpl::DeleteSurroundingText(int _t1, unsigned int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void fcitx::FcitxQtInputContextProxyImpl::ForwardKey(unsigned int _t1, unsigned int _t2, bool _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void fcitx::FcitxQtInputContextProxyImpl::NotifyFocusOut()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void fcitx::FcitxQtInputContextProxyImpl::UpdateClientSideUI(FcitxQtFormattedPreeditList _t1, int _t2, FcitxQtFormattedPreeditList _t3, FcitxQtFormattedPreeditList _t4, FcitxQtStringKeyValueList _t5, int _t6, int _t7, bool _t8, bool _t9)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t6))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t7))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t8))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t9))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void fcitx::FcitxQtInputContextProxyImpl::UpdateFormattedPreedit(FcitxQtFormattedPreeditList _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void fcitx::FcitxQtInputContextProxyImpl::VirtualKeyboardVisibilityChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
