/****************************************************************************
** Meta object code from reading C++ file 'fcitx4inputcontextproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../fcitx4inputcontextproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fcitx4inputcontextproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5fcitx23Fcitx4InputContextProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto fcitx::Fcitx4InputContextProxy::qt_create_metaobjectdata<qt_meta_tag_ZN5fcitx23Fcitx4InputContextProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "fcitx::Fcitx4InputContextProxy",
        "commitString",
        "",
        "str",
        "currentIM",
        "name",
        "uniqueName",
        "langCode",
        "deleteSurroundingText",
        "offset",
        "nchar",
        "forwardKey",
        "keyval",
        "state",
        "isRelease",
        "updateFormattedPreedit",
        "FcitxQtFormattedPreeditList",
        "cursorpos",
        "inputContextCreated",
        "focusIn",
        "QDBusPendingReply<>",
        "focusOut",
        "processKeyEvent",
        "QDBusPendingReply<int>",
        "keycode",
        "type",
        "time",
        "reset",
        "setCapability",
        "caps",
        "setCursorRect",
        "x",
        "y",
        "w",
        "h",
        "setSurroundingText",
        "text",
        "cursor",
        "anchor",
        "setSurroundingTextPosition"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'commitString'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'currentIM'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'deleteSurroundingText'
        QtMocHelpers::SignalData<void(int, unsigned int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 }, { QMetaType::UInt, 10 },
        }}),
        // Signal 'forwardKey'
        QtMocHelpers::SignalData<void(unsigned int, unsigned int, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 12 }, { QMetaType::UInt, 13 }, { QMetaType::Bool, 14 },
        }}),
        // Signal 'updateFormattedPreedit'
        QtMocHelpers::SignalData<void(const FcitxQtFormattedPreeditList &, int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 3 }, { QMetaType::Int, 17 },
        }}),
        // Signal 'inputContextCreated'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'focusIn'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(19, 2, QMC::AccessPublic, 0x80000000 | 20),
        // Slot 'focusOut'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(21, 2, QMC::AccessPublic, 0x80000000 | 20),
        // Slot 'processKeyEvent'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(unsigned int, unsigned int, unsigned int, int, unsigned int)>(22, 2, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::UInt, 12 }, { QMetaType::UInt, 24 }, { QMetaType::UInt, 13 }, { QMetaType::Int, 25 },
            { QMetaType::UInt, 26 },
        }}),
        // Slot 'reset'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(27, 2, QMC::AccessPublic, 0x80000000 | 20),
        // Slot 'setCapability'
        QtMocHelpers::SlotData<QDBusPendingReply<>(unsigned int)>(28, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::UInt, 29 },
        }}),
        // Slot 'setCursorRect'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, int, int, int)>(30, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::Int, 31 }, { QMetaType::Int, 32 }, { QMetaType::Int, 33 }, { QMetaType::Int, 34 },
        }}),
        // Slot 'setSurroundingText'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, unsigned int, unsigned int)>(35, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::QString, 36 }, { QMetaType::UInt, 37 }, { QMetaType::UInt, 38 },
        }}),
        // Slot 'setSurroundingTextPosition'
        QtMocHelpers::SlotData<QDBusPendingReply<>(unsigned int, unsigned int)>(39, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::UInt, 37 }, { QMetaType::UInt, 38 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Fcitx4InputContextProxy, qt_meta_tag_ZN5fcitx23Fcitx4InputContextProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject fcitx::Fcitx4InputContextProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx23Fcitx4InputContextProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx23Fcitx4InputContextProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5fcitx23Fcitx4InputContextProxyE_t>.metaTypes,
    nullptr
} };

void fcitx::Fcitx4InputContextProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Fcitx4InputContextProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->commitString((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->currentIM((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->deleteSurroundingText((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 3: _t->forwardKey((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 4: _t->updateFormattedPreedit((*reinterpret_cast<std::add_pointer_t<FcitxQtFormattedPreeditList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->inputContextCreated(); break;
        case 6: { QDBusPendingReply<> _r = _t->focusIn();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->focusOut();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<int> _r = _t->processKeyEvent((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->reset();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->setCapability((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->setCursorRect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->setSurroundingText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<> _r = _t->setSurroundingTextPosition((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Fcitx4InputContextProxy::*)(const QString & )>(_a, &Fcitx4InputContextProxy::commitString, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Fcitx4InputContextProxy::*)(const QString & , const QString & , const QString & )>(_a, &Fcitx4InputContextProxy::currentIM, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Fcitx4InputContextProxy::*)(int , unsigned int )>(_a, &Fcitx4InputContextProxy::deleteSurroundingText, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Fcitx4InputContextProxy::*)(unsigned int , unsigned int , bool )>(_a, &Fcitx4InputContextProxy::forwardKey, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Fcitx4InputContextProxy::*)(const FcitxQtFormattedPreeditList & , int )>(_a, &Fcitx4InputContextProxy::updateFormattedPreedit, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Fcitx4InputContextProxy::*)()>(_a, &Fcitx4InputContextProxy::inputContextCreated, 5))
            return;
    }
}

const QMetaObject *fcitx::Fcitx4InputContextProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::Fcitx4InputContextProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx23Fcitx4InputContextProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int fcitx::Fcitx4InputContextProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void fcitx::Fcitx4InputContextProxy::commitString(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void fcitx::Fcitx4InputContextProxy::currentIM(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void fcitx::Fcitx4InputContextProxy::deleteSurroundingText(int _t1, unsigned int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void fcitx::Fcitx4InputContextProxy::forwardKey(unsigned int _t1, unsigned int _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void fcitx::Fcitx4InputContextProxy::updateFormattedPreedit(const FcitxQtFormattedPreeditList & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void fcitx::Fcitx4InputContextProxy::inputContextCreated()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
