/****************************************************************************
** Meta object code from reading C++ file 'fcitx4inputcontextproxy.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../fcitx4inputcontextproxy.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fcitx4inputcontextproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_fcitx__Fcitx4InputContextProxy_t {
    QByteArrayData data[40];
    char stringdata0[440];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_fcitx__Fcitx4InputContextProxy_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_fcitx__Fcitx4InputContextProxy_t qt_meta_stringdata_fcitx__Fcitx4InputContextProxy = {
    {
QT_MOC_LITERAL(0, 0, 30), // "fcitx::Fcitx4InputContextProxy"
QT_MOC_LITERAL(1, 31, 12), // "commitString"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 3), // "str"
QT_MOC_LITERAL(4, 49, 9), // "currentIM"
QT_MOC_LITERAL(5, 59, 4), // "name"
QT_MOC_LITERAL(6, 64, 10), // "uniqueName"
QT_MOC_LITERAL(7, 75, 8), // "langCode"
QT_MOC_LITERAL(8, 84, 21), // "deleteSurroundingText"
QT_MOC_LITERAL(9, 106, 6), // "offset"
QT_MOC_LITERAL(10, 113, 5), // "nchar"
QT_MOC_LITERAL(11, 119, 10), // "forwardKey"
QT_MOC_LITERAL(12, 130, 6), // "keyval"
QT_MOC_LITERAL(13, 137, 5), // "state"
QT_MOC_LITERAL(14, 143, 9), // "isRelease"
QT_MOC_LITERAL(15, 153, 22), // "updateFormattedPreedit"
QT_MOC_LITERAL(16, 176, 27), // "FcitxQtFormattedPreeditList"
QT_MOC_LITERAL(17, 204, 9), // "cursorpos"
QT_MOC_LITERAL(18, 214, 19), // "inputContextCreated"
QT_MOC_LITERAL(19, 234, 7), // "focusIn"
QT_MOC_LITERAL(20, 242, 19), // "QDBusPendingReply<>"
QT_MOC_LITERAL(21, 262, 8), // "focusOut"
QT_MOC_LITERAL(22, 271, 15), // "processKeyEvent"
QT_MOC_LITERAL(23, 287, 22), // "QDBusPendingReply<int>"
QT_MOC_LITERAL(24, 310, 7), // "keycode"
QT_MOC_LITERAL(25, 318, 4), // "type"
QT_MOC_LITERAL(26, 323, 4), // "time"
QT_MOC_LITERAL(27, 328, 5), // "reset"
QT_MOC_LITERAL(28, 334, 13), // "setCapability"
QT_MOC_LITERAL(29, 348, 4), // "caps"
QT_MOC_LITERAL(30, 353, 13), // "setCursorRect"
QT_MOC_LITERAL(31, 367, 1), // "x"
QT_MOC_LITERAL(32, 369, 1), // "y"
QT_MOC_LITERAL(33, 371, 1), // "w"
QT_MOC_LITERAL(34, 373, 1), // "h"
QT_MOC_LITERAL(35, 375, 18), // "setSurroundingText"
QT_MOC_LITERAL(36, 394, 4), // "text"
QT_MOC_LITERAL(37, 399, 6), // "cursor"
QT_MOC_LITERAL(38, 406, 6), // "anchor"
QT_MOC_LITERAL(39, 413, 26) // "setSurroundingTextPosition"

    },
    "fcitx::Fcitx4InputContextProxy\0"
    "commitString\0\0str\0currentIM\0name\0"
    "uniqueName\0langCode\0deleteSurroundingText\0"
    "offset\0nchar\0forwardKey\0keyval\0state\0"
    "isRelease\0updateFormattedPreedit\0"
    "FcitxQtFormattedPreeditList\0cursorpos\0"
    "inputContextCreated\0focusIn\0"
    "QDBusPendingReply<>\0focusOut\0"
    "processKeyEvent\0QDBusPendingReply<int>\0"
    "keycode\0type\0time\0reset\0setCapability\0"
    "caps\0setCursorRect\0x\0y\0w\0h\0"
    "setSurroundingText\0text\0cursor\0anchor\0"
    "setSurroundingTextPosition"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_fcitx__Fcitx4InputContextProxy[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   84,    2, 0x06 /* Public */,
       4,    3,   87,    2, 0x06 /* Public */,
       8,    2,   94,    2, 0x06 /* Public */,
      11,    3,   99,    2, 0x06 /* Public */,
      15,    2,  106,    2, 0x06 /* Public */,
      18,    0,  111,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      19,    0,  112,    2, 0x0a /* Public */,
      21,    0,  113,    2, 0x0a /* Public */,
      22,    5,  114,    2, 0x0a /* Public */,
      27,    0,  125,    2, 0x0a /* Public */,
      28,    1,  126,    2, 0x0a /* Public */,
      30,    4,  129,    2, 0x0a /* Public */,
      35,    3,  138,    2, 0x0a /* Public */,
      39,    2,  145,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,    5,    6,    7,
    QMetaType::Void, QMetaType::Int, QMetaType::UInt,    9,   10,
    QMetaType::Void, QMetaType::UInt, QMetaType::UInt, QMetaType::Bool,   12,   13,   14,
    QMetaType::Void, 0x80000000 | 16, QMetaType::Int,    3,   17,
    QMetaType::Void,

 // slots: parameters
    0x80000000 | 20,
    0x80000000 | 20,
    0x80000000 | 23, QMetaType::UInt, QMetaType::UInt, QMetaType::UInt, QMetaType::Int, QMetaType::UInt,   12,   24,   13,   25,   26,
    0x80000000 | 20,
    0x80000000 | 20, QMetaType::UInt,   29,
    0x80000000 | 20, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,   31,   32,   33,   34,
    0x80000000 | 20, QMetaType::QString, QMetaType::UInt, QMetaType::UInt,   36,   37,   38,
    0x80000000 | 20, QMetaType::UInt, QMetaType::UInt,   37,   38,

       0        // eod
};

void fcitx::Fcitx4InputContextProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Fcitx4InputContextProxy *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->commitString((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->currentIM((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 2: _t->deleteSurroundingText((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 3: _t->forwardKey((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 4: _t->updateFormattedPreedit((*reinterpret_cast< const FcitxQtFormattedPreeditList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 5: _t->inputContextCreated(); break;
        case 6: { QDBusPendingReply<> _r = _t->focusIn();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->focusOut();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<int> _r = _t->processKeyEvent((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< uint(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->reset();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->setCapability((*reinterpret_cast< uint(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->setCursorRect((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->setSurroundingText((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<> _r = _t->setSurroundingTextPosition((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Fcitx4InputContextProxy::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Fcitx4InputContextProxy::commitString)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Fcitx4InputContextProxy::*)(const QString & , const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Fcitx4InputContextProxy::currentIM)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Fcitx4InputContextProxy::*)(int , unsigned int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Fcitx4InputContextProxy::deleteSurroundingText)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Fcitx4InputContextProxy::*)(unsigned int , unsigned int , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Fcitx4InputContextProxy::forwardKey)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Fcitx4InputContextProxy::*)(const FcitxQtFormattedPreeditList & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Fcitx4InputContextProxy::updateFormattedPreedit)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (Fcitx4InputContextProxy::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Fcitx4InputContextProxy::inputContextCreated)) {
                *result = 5;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject fcitx::Fcitx4InputContextProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_fcitx__Fcitx4InputContextProxy.data,
    qt_meta_data_fcitx__Fcitx4InputContextProxy,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *fcitx::Fcitx4InputContextProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::Fcitx4InputContextProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_fcitx__Fcitx4InputContextProxy.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int fcitx::Fcitx4InputContextProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void fcitx::Fcitx4InputContextProxy::commitString(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void fcitx::Fcitx4InputContextProxy::currentIM(const QString & _t1, const QString & _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void fcitx::Fcitx4InputContextProxy::deleteSurroundingText(int _t1, unsigned int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void fcitx::Fcitx4InputContextProxy::forwardKey(unsigned int _t1, unsigned int _t2, bool _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void fcitx::Fcitx4InputContextProxy::updateFormattedPreedit(const FcitxQtFormattedPreeditList & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void fcitx::Fcitx4InputContextProxy::inputContextCreated()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
