/********************************************************************************
** Form generated from reading UI file 'editordialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITORDIALOG_H
#define UI_EDITORDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <fcitxqti18nhelper.h>

QT_BEGIN_NAMESPACE

class Ui_EditorDialog
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLineEdit *keyLineEdit;
    QLabel *keyLabel;
    QLineEdit *valueLineEdit;
    QLabel *valueLabel;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *EditorDialog)
    {
        if (EditorDialog->objectName().isEmpty())
            EditorDialog->setObjectName("EditorDialog");
        EditorDialog->resize(334, 133);
        verticalLayout = new QVBoxLayout(EditorDialog);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        keyLineEdit = new QLineEdit(EditorDialog);
        keyLineEdit->setObjectName("keyLineEdit");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, keyLineEdit);

        keyLabel = new QLabel(EditorDialog);
        keyLabel->setObjectName("keyLabel");
        keyLabel->setText(QString::fromUtf8("Keyword:"));

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, keyLabel);

        valueLineEdit = new QLineEdit(EditorDialog);
        valueLineEdit->setObjectName("valueLineEdit");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, valueLineEdit);

        valueLabel = new QLabel(EditorDialog);
        valueLabel->setObjectName("valueLabel");
        valueLabel->setText(QString::fromUtf8("Phrase:"));

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, valueLabel);


        verticalLayout->addLayout(formLayout);

        buttonBox = new QDialogButtonBox(EditorDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(EditorDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, EditorDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, EditorDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(EditorDialog);
    } // setupUi

    void retranslateUi(QDialog *EditorDialog)
    {
        (void)EditorDialog;
    } // retranslateUi

};

namespace Ui {
    class EditorDialog: public Ui_EditorDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EDITORDIALOG_H
