/****************************************************************************
** Meta object code from reading C++ file 'fcitx4inputcontextproxyimpl.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../fcitx4inputcontextproxyimpl.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fcitx4inputcontextproxyimpl.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_fcitx__Fcitx4InputContextProxyImpl_t {
    QByteArrayData data[39];
    char stringdata0[422];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_fcitx__Fcitx4InputContextProxyImpl_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_fcitx__Fcitx4InputContextProxyImpl_t qt_meta_stringdata_fcitx__Fcitx4InputContextProxyImpl = {
    {
QT_MOC_LITERAL(0, 0, 34), // "fcitx::Fcitx4InputContextProx..."
QT_MOC_LITERAL(1, 35, 12), // "CommitString"
QT_MOC_LITERAL(2, 48, 0), // ""
QT_MOC_LITERAL(3, 49, 3), // "str"
QT_MOC_LITERAL(4, 53, 9), // "CurrentIM"
QT_MOC_LITERAL(5, 63, 4), // "name"
QT_MOC_LITERAL(6, 68, 10), // "uniqueName"
QT_MOC_LITERAL(7, 79, 8), // "langCode"
QT_MOC_LITERAL(8, 88, 21), // "DeleteSurroundingText"
QT_MOC_LITERAL(9, 110, 6), // "offset"
QT_MOC_LITERAL(10, 117, 5), // "nchar"
QT_MOC_LITERAL(11, 123, 10), // "ForwardKey"
QT_MOC_LITERAL(12, 134, 6), // "keyval"
QT_MOC_LITERAL(13, 141, 5), // "state"
QT_MOC_LITERAL(14, 147, 4), // "type"
QT_MOC_LITERAL(15, 152, 22), // "UpdateFormattedPreedit"
QT_MOC_LITERAL(16, 175, 27), // "FcitxQtFormattedPreeditList"
QT_MOC_LITERAL(17, 203, 9), // "cursorpos"
QT_MOC_LITERAL(18, 213, 9), // "DestroyIC"
QT_MOC_LITERAL(19, 223, 19), // "QDBusPendingReply<>"
QT_MOC_LITERAL(20, 243, 7), // "FocusIn"
QT_MOC_LITERAL(21, 251, 8), // "FocusOut"
QT_MOC_LITERAL(22, 260, 15), // "ProcessKeyEvent"
QT_MOC_LITERAL(23, 276, 22), // "QDBusPendingReply<int>"
QT_MOC_LITERAL(24, 299, 7), // "keycode"
QT_MOC_LITERAL(25, 307, 4), // "time"
QT_MOC_LITERAL(26, 312, 5), // "Reset"
QT_MOC_LITERAL(27, 318, 11), // "SetCapacity"
QT_MOC_LITERAL(28, 330, 4), // "caps"
QT_MOC_LITERAL(29, 335, 13), // "SetCursorRect"
QT_MOC_LITERAL(30, 349, 1), // "x"
QT_MOC_LITERAL(31, 351, 1), // "y"
QT_MOC_LITERAL(32, 353, 1), // "w"
QT_MOC_LITERAL(33, 355, 1), // "h"
QT_MOC_LITERAL(34, 357, 18), // "SetSurroundingText"
QT_MOC_LITERAL(35, 376, 4), // "text"
QT_MOC_LITERAL(36, 381, 6), // "cursor"
QT_MOC_LITERAL(37, 388, 6), // "anchor"
QT_MOC_LITERAL(38, 395, 26) // "SetSurroundingTextPosition"

    },
    "fcitx::Fcitx4InputContextProxyImpl\0"
    "CommitString\0\0str\0CurrentIM\0name\0"
    "uniqueName\0langCode\0DeleteSurroundingText\0"
    "offset\0nchar\0ForwardKey\0keyval\0state\0"
    "type\0UpdateFormattedPreedit\0"
    "FcitxQtFormattedPreeditList\0cursorpos\0"
    "DestroyIC\0QDBusPendingReply<>\0FocusIn\0"
    "FocusOut\0ProcessKeyEvent\0"
    "QDBusPendingReply<int>\0keycode\0time\0"
    "Reset\0SetCapacity\0caps\0SetCursorRect\0"
    "x\0y\0w\0h\0SetSurroundingText\0text\0cursor\0"
    "anchor\0SetSurroundingTextPosition"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_fcitx__Fcitx4InputContextProxyImpl[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   84,    2, 0x06 /* Public */,
       4,    3,   87,    2, 0x06 /* Public */,
       8,    2,   94,    2, 0x06 /* Public */,
      11,    3,   99,    2, 0x06 /* Public */,
      15,    2,  106,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      18,    0,  111,    2, 0x0a /* Public */,
      20,    0,  112,    2, 0x0a /* Public */,
      21,    0,  113,    2, 0x0a /* Public */,
      22,    5,  114,    2, 0x0a /* Public */,
      26,    0,  125,    2, 0x0a /* Public */,
      27,    1,  126,    2, 0x0a /* Public */,
      29,    4,  129,    2, 0x0a /* Public */,
      34,    3,  138,    2, 0x0a /* Public */,
      38,    2,  145,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,    5,    6,    7,
    QMetaType::Void, QMetaType::Int, QMetaType::UInt,    9,   10,
    QMetaType::Void, QMetaType::UInt, QMetaType::UInt, QMetaType::Int,   12,   13,   14,
    QMetaType::Void, 0x80000000 | 16, QMetaType::Int,    3,   17,

 // slots: parameters
    0x80000000 | 19,
    0x80000000 | 19,
    0x80000000 | 19,
    0x80000000 | 23, QMetaType::UInt, QMetaType::UInt, QMetaType::UInt, QMetaType::Int, QMetaType::UInt,   12,   24,   13,   14,   25,
    0x80000000 | 19,
    0x80000000 | 19, QMetaType::UInt,   28,
    0x80000000 | 19, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,   30,   31,   32,   33,
    0x80000000 | 19, QMetaType::QString, QMetaType::UInt, QMetaType::UInt,   35,   36,   37,
    0x80000000 | 19, QMetaType::UInt, QMetaType::UInt,   36,   37,

       0        // eod
};

void fcitx::Fcitx4InputContextProxyImpl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Fcitx4InputContextProxyImpl *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->CommitString((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->CurrentIM((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 2: _t->DeleteSurroundingText((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 3: _t->ForwardKey((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 4: _t->UpdateFormattedPreedit((*reinterpret_cast< FcitxQtFormattedPreeditList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 5: { QDBusPendingReply<> _r = _t->DestroyIC();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<> _r = _t->FocusIn();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->FocusOut();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<int> _r = _t->ProcessKeyEvent((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< uint(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->Reset();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->SetCapacity((*reinterpret_cast< uint(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->SetCursorRect((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->SetSurroundingText((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<> _r = _t->SetSurroundingTextPosition((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Fcitx4InputContextProxyImpl::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Fcitx4InputContextProxyImpl::CommitString)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Fcitx4InputContextProxyImpl::*)(const QString & , const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Fcitx4InputContextProxyImpl::CurrentIM)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Fcitx4InputContextProxyImpl::*)(int , unsigned int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Fcitx4InputContextProxyImpl::DeleteSurroundingText)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Fcitx4InputContextProxyImpl::*)(unsigned int , unsigned int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Fcitx4InputContextProxyImpl::ForwardKey)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Fcitx4InputContextProxyImpl::*)(FcitxQtFormattedPreeditList , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Fcitx4InputContextProxyImpl::UpdateFormattedPreedit)) {
                *result = 4;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject fcitx::Fcitx4InputContextProxyImpl::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_meta_stringdata_fcitx__Fcitx4InputContextProxyImpl.data,
    qt_meta_data_fcitx__Fcitx4InputContextProxyImpl,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *fcitx::Fcitx4InputContextProxyImpl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::Fcitx4InputContextProxyImpl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_fcitx__Fcitx4InputContextProxyImpl.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int fcitx::Fcitx4InputContextProxyImpl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void fcitx::Fcitx4InputContextProxyImpl::CommitString(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void fcitx::Fcitx4InputContextProxyImpl::CurrentIM(const QString & _t1, const QString & _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void fcitx::Fcitx4InputContextProxyImpl::DeleteSurroundingText(int _t1, unsigned int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void fcitx::Fcitx4InputContextProxyImpl::ForwardKey(unsigned int _t1, unsigned int _t2, int _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void fcitx::Fcitx4InputContextProxyImpl::UpdateFormattedPreedit(FcitxQtFormattedPreeditList _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
