/****************************************************************************
** Meta object code from reading C++ file 'fcitxqtinputcontextproxy.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../fcitxqtinputcontextproxy.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fcitxqtinputcontextproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_fcitx__FcitxQtInputContextProxy_t {
    QByteArrayData data[68];
    char stringdata0[836];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_fcitx__FcitxQtInputContextProxy_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_fcitx__FcitxQtInputContextProxy_t qt_meta_stringdata_fcitx__FcitxQtInputContextProxy = {
    {
QT_MOC_LITERAL(0, 0, 31), // "fcitx::FcitxQtInputContextProxy"
QT_MOC_LITERAL(1, 32, 12), // "commitString"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 3), // "str"
QT_MOC_LITERAL(4, 50, 9), // "currentIM"
QT_MOC_LITERAL(5, 60, 4), // "name"
QT_MOC_LITERAL(6, 65, 10), // "uniqueName"
QT_MOC_LITERAL(7, 76, 8), // "langCode"
QT_MOC_LITERAL(8, 85, 21), // "deleteSurroundingText"
QT_MOC_LITERAL(9, 107, 6), // "offset"
QT_MOC_LITERAL(10, 114, 5), // "nchar"
QT_MOC_LITERAL(11, 120, 10), // "forwardKey"
QT_MOC_LITERAL(12, 131, 6), // "keyval"
QT_MOC_LITERAL(13, 138, 5), // "state"
QT_MOC_LITERAL(14, 144, 9), // "isRelease"
QT_MOC_LITERAL(15, 154, 22), // "updateFormattedPreedit"
QT_MOC_LITERAL(16, 177, 27), // "FcitxQtFormattedPreeditList"
QT_MOC_LITERAL(17, 205, 9), // "cursorpos"
QT_MOC_LITERAL(18, 215, 18), // "updateClientSideUI"
QT_MOC_LITERAL(19, 234, 7), // "preedit"
QT_MOC_LITERAL(20, 242, 5), // "auxUp"
QT_MOC_LITERAL(21, 248, 7), // "auxDown"
QT_MOC_LITERAL(22, 256, 25), // "FcitxQtStringKeyValueList"
QT_MOC_LITERAL(23, 282, 10), // "candidates"
QT_MOC_LITERAL(24, 293, 14), // "candidateIndex"
QT_MOC_LITERAL(25, 308, 10), // "layoutHint"
QT_MOC_LITERAL(26, 319, 7), // "hasPrev"
QT_MOC_LITERAL(27, 327, 7), // "hasNext"
QT_MOC_LITERAL(28, 335, 19), // "inputContextCreated"
QT_MOC_LITERAL(29, 355, 4), // "uuid"
QT_MOC_LITERAL(30, 360, 26), // "inputContextCreationFailed"
QT_MOC_LITERAL(31, 387, 14), // "notifyFocusOut"
QT_MOC_LITERAL(32, 402, 32), // "virtualKeyboardVisibilityChanged"
QT_MOC_LITERAL(33, 435, 7), // "visible"
QT_MOC_LITERAL(34, 443, 7), // "focusIn"
QT_MOC_LITERAL(35, 451, 19), // "QDBusPendingReply<>"
QT_MOC_LITERAL(36, 471, 8), // "focusOut"
QT_MOC_LITERAL(37, 480, 19), // "hideVirtualKeyboard"
QT_MOC_LITERAL(38, 500, 15), // "processKeyEvent"
QT_MOC_LITERAL(39, 516, 23), // "QDBusPendingReply<bool>"
QT_MOC_LITERAL(40, 540, 7), // "keycode"
QT_MOC_LITERAL(41, 548, 4), // "type"
QT_MOC_LITERAL(42, 553, 4), // "time"
QT_MOC_LITERAL(43, 558, 5), // "reset"
QT_MOC_LITERAL(44, 564, 22), // "setSupportedCapability"
QT_MOC_LITERAL(45, 587, 4), // "caps"
QT_MOC_LITERAL(46, 592, 13), // "setCapability"
QT_MOC_LITERAL(47, 606, 13), // "setCursorRect"
QT_MOC_LITERAL(48, 620, 1), // "x"
QT_MOC_LITERAL(49, 622, 1), // "y"
QT_MOC_LITERAL(50, 624, 1), // "w"
QT_MOC_LITERAL(51, 626, 1), // "h"
QT_MOC_LITERAL(52, 628, 15), // "setCursorRectV2"
QT_MOC_LITERAL(53, 644, 5), // "scale"
QT_MOC_LITERAL(54, 650, 18), // "setSurroundingText"
QT_MOC_LITERAL(55, 669, 4), // "text"
QT_MOC_LITERAL(56, 674, 6), // "cursor"
QT_MOC_LITERAL(57, 681, 6), // "anchor"
QT_MOC_LITERAL(58, 688, 26), // "setSurroundingTextPosition"
QT_MOC_LITERAL(59, 715, 19), // "showVirtualKeyboard"
QT_MOC_LITERAL(60, 735, 8), // "prevPage"
QT_MOC_LITERAL(61, 744, 8), // "nextPage"
QT_MOC_LITERAL(62, 753, 15), // "selectCandidate"
QT_MOC_LITERAL(63, 769, 1), // "i"
QT_MOC_LITERAL(64, 771, 12), // "invokeAction"
QT_MOC_LITERAL(65, 784, 6), // "action"
QT_MOC_LITERAL(66, 791, 24), // "isVirtualKeyboardVisible"
QT_MOC_LITERAL(67, 816, 19) // "supportInvokeAction"

    },
    "fcitx::FcitxQtInputContextProxy\0"
    "commitString\0\0str\0currentIM\0name\0"
    "uniqueName\0langCode\0deleteSurroundingText\0"
    "offset\0nchar\0forwardKey\0keyval\0state\0"
    "isRelease\0updateFormattedPreedit\0"
    "FcitxQtFormattedPreeditList\0cursorpos\0"
    "updateClientSideUI\0preedit\0auxUp\0"
    "auxDown\0FcitxQtStringKeyValueList\0"
    "candidates\0candidateIndex\0layoutHint\0"
    "hasPrev\0hasNext\0inputContextCreated\0"
    "uuid\0inputContextCreationFailed\0"
    "notifyFocusOut\0virtualKeyboardVisibilityChanged\0"
    "visible\0focusIn\0QDBusPendingReply<>\0"
    "focusOut\0hideVirtualKeyboard\0"
    "processKeyEvent\0QDBusPendingReply<bool>\0"
    "keycode\0type\0time\0reset\0setSupportedCapability\0"
    "caps\0setCapability\0setCursorRect\0x\0y\0"
    "w\0h\0setCursorRectV2\0scale\0setSurroundingText\0"
    "text\0cursor\0anchor\0setSurroundingTextPosition\0"
    "showVirtualKeyboard\0prevPage\0nextPage\0"
    "selectCandidate\0i\0invokeAction\0action\0"
    "isVirtualKeyboardVisible\0supportInvokeAction"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_fcitx__FcitxQtInputContextProxy[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      28,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  154,    2, 0x06 /* Public */,
       4,    3,  157,    2, 0x06 /* Public */,
       8,    2,  164,    2, 0x06 /* Public */,
      11,    3,  169,    2, 0x06 /* Public */,
      15,    2,  176,    2, 0x06 /* Public */,
      18,    9,  181,    2, 0x06 /* Public */,
      28,    1,  200,    2, 0x06 /* Public */,
      30,    0,  203,    2, 0x06 /* Public */,
      31,    0,  204,    2, 0x06 /* Public */,
      32,    1,  205,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      34,    0,  208,    2, 0x0a /* Public */,
      36,    0,  209,    2, 0x0a /* Public */,
      37,    0,  210,    2, 0x0a /* Public */,
      38,    5,  211,    2, 0x0a /* Public */,
      43,    0,  222,    2, 0x0a /* Public */,
      44,    1,  223,    2, 0x0a /* Public */,
      46,    1,  226,    2, 0x0a /* Public */,
      47,    4,  229,    2, 0x0a /* Public */,
      52,    5,  238,    2, 0x0a /* Public */,
      54,    3,  249,    2, 0x0a /* Public */,
      58,    2,  256,    2, 0x0a /* Public */,
      59,    0,  261,    2, 0x0a /* Public */,
      60,    0,  262,    2, 0x0a /* Public */,
      61,    0,  263,    2, 0x0a /* Public */,
      62,    1,  264,    2, 0x0a /* Public */,
      64,    2,  267,    2, 0x0a /* Public */,
      66,    0,  272,    2, 0x0a /* Public */,
      67,    0,  273,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,    5,    6,    7,
    QMetaType::Void, QMetaType::Int, QMetaType::UInt,    9,   10,
    QMetaType::Void, QMetaType::UInt, QMetaType::UInt, QMetaType::Bool,   12,   13,   14,
    QMetaType::Void, 0x80000000 | 16, QMetaType::Int,    3,   17,
    QMetaType::Void, 0x80000000 | 16, QMetaType::Int, 0x80000000 | 16, 0x80000000 | 16, 0x80000000 | 22, QMetaType::Int, QMetaType::Int, QMetaType::Bool, QMetaType::Bool,   19,   17,   20,   21,   23,   24,   25,   26,   27,
    QMetaType::Void, QMetaType::QByteArray,   29,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   33,

 // slots: parameters
    0x80000000 | 35,
    0x80000000 | 35,
    0x80000000 | 35,
    0x80000000 | 39, QMetaType::UInt, QMetaType::UInt, QMetaType::UInt, QMetaType::Bool, QMetaType::UInt,   12,   40,   13,   41,   42,
    0x80000000 | 35,
    0x80000000 | 35, QMetaType::ULongLong,   45,
    0x80000000 | 35, QMetaType::ULongLong,   45,
    0x80000000 | 35, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,   48,   49,   50,   51,
    0x80000000 | 35, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Double,   48,   49,   50,   51,   53,
    0x80000000 | 35, QMetaType::QString, QMetaType::UInt, QMetaType::UInt,   55,   56,   57,
    0x80000000 | 35, QMetaType::UInt, QMetaType::UInt,   56,   57,
    0x80000000 | 35,
    0x80000000 | 35,
    0x80000000 | 35,
    0x80000000 | 35, QMetaType::Int,   63,
    0x80000000 | 35, QMetaType::UInt, QMetaType::Int,   65,   56,
    QMetaType::Bool,
    QMetaType::Bool,

       0        // eod
};

void fcitx::FcitxQtInputContextProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<FcitxQtInputContextProxy *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->commitString((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->currentIM((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 2: _t->deleteSurroundingText((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 3: _t->forwardKey((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 4: _t->updateFormattedPreedit((*reinterpret_cast< const FcitxQtFormattedPreeditList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 5: _t->updateClientSideUI((*reinterpret_cast< const FcitxQtFormattedPreeditList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const FcitxQtFormattedPreeditList(*)>(_a[3])),(*reinterpret_cast< const FcitxQtFormattedPreeditList(*)>(_a[4])),(*reinterpret_cast< const FcitxQtStringKeyValueList(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7])),(*reinterpret_cast< bool(*)>(_a[8])),(*reinterpret_cast< bool(*)>(_a[9]))); break;
        case 6: _t->inputContextCreated((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 7: _t->inputContextCreationFailed(); break;
        case 8: _t->notifyFocusOut(); break;
        case 9: _t->virtualKeyboardVisibilityChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: { QDBusPendingReply<> _r = _t->focusIn();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->focusOut();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->hideVirtualKeyboard();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<bool> _r = _t->processKeyEvent((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< uint(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<> _r = _t->reset();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<> _r = _t->setSupportedCapability((*reinterpret_cast< qulonglong(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<> _r = _t->setCapability((*reinterpret_cast< qulonglong(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->setCursorRect((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->setCursorRectV2((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< double(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->setSurroundingText((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<> _r = _t->setSurroundingTextPosition((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<> _r = _t->showVirtualKeyboard();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->prevPage();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<> _r = _t->nextPage();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->selectCandidate((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<> _r = _t->invokeAction((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 26: { bool _r = _t->isVirtualKeyboardVisible();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->supportInvokeAction();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (FcitxQtInputContextProxy::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtInputContextProxy::commitString)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (FcitxQtInputContextProxy::*)(const QString & , const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtInputContextProxy::currentIM)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (FcitxQtInputContextProxy::*)(int , unsigned int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtInputContextProxy::deleteSurroundingText)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (FcitxQtInputContextProxy::*)(unsigned int , unsigned int , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtInputContextProxy::forwardKey)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (FcitxQtInputContextProxy::*)(const FcitxQtFormattedPreeditList & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtInputContextProxy::updateFormattedPreedit)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (FcitxQtInputContextProxy::*)(const FcitxQtFormattedPreeditList & , int , const FcitxQtFormattedPreeditList & , const FcitxQtFormattedPreeditList & , const FcitxQtStringKeyValueList & , int , int , bool , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtInputContextProxy::updateClientSideUI)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (FcitxQtInputContextProxy::*)(const QByteArray & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtInputContextProxy::inputContextCreated)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (FcitxQtInputContextProxy::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtInputContextProxy::inputContextCreationFailed)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (FcitxQtInputContextProxy::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtInputContextProxy::notifyFocusOut)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (FcitxQtInputContextProxy::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtInputContextProxy::virtualKeyboardVisibilityChanged)) {
                *result = 9;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject fcitx::FcitxQtInputContextProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_fcitx__FcitxQtInputContextProxy.data,
    qt_meta_data_fcitx__FcitxQtInputContextProxy,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *fcitx::FcitxQtInputContextProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::FcitxQtInputContextProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_fcitx__FcitxQtInputContextProxy.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int fcitx::FcitxQtInputContextProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void fcitx::FcitxQtInputContextProxy::commitString(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void fcitx::FcitxQtInputContextProxy::currentIM(const QString & _t1, const QString & _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void fcitx::FcitxQtInputContextProxy::deleteSurroundingText(int _t1, unsigned int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void fcitx::FcitxQtInputContextProxy::forwardKey(unsigned int _t1, unsigned int _t2, bool _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void fcitx::FcitxQtInputContextProxy::updateFormattedPreedit(const FcitxQtFormattedPreeditList & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void fcitx::FcitxQtInputContextProxy::updateClientSideUI(const FcitxQtFormattedPreeditList & _t1, int _t2, const FcitxQtFormattedPreeditList & _t3, const FcitxQtFormattedPreeditList & _t4, const FcitxQtStringKeyValueList & _t5, int _t6, int _t7, bool _t8, bool _t9)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t6))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t7))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t8))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t9))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void fcitx::FcitxQtInputContextProxy::inputContextCreated(const QByteArray & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void fcitx::FcitxQtInputContextProxy::inputContextCreationFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void fcitx::FcitxQtInputContextProxy::notifyFocusOut()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void fcitx::FcitxQtInputContextProxy::virtualKeyboardVisibilityChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
