/****************************************************************************
** Meta object code from reading C++ file 'fcitxcandidatewindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../fcitxcandidatewindow.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fcitxcandidatewindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5fcitx20FcitxCandidateWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto fcitx::FcitxCandidateWindow::qt_create_metaobjectdata<qt_meta_tag_ZN5fcitx20FcitxCandidateWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "fcitx::FcitxCandidateWindow",
        "candidateSelected",
        "",
        "i",
        "prevClicked",
        "nextClicked",
        "updateClientSideUI",
        "FcitxQtFormattedPreeditList",
        "preedit",
        "cursorpos",
        "auxUp",
        "auxDown",
        "FcitxQtStringKeyValueList",
        "candidates",
        "candidateIndex",
        "layoutHint",
        "hasPrev",
        "hasNext",
        "updatePosition",
        "sizeHint",
        "QSize"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'candidateSelected'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'prevClicked'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextClicked'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateClientSideUI'
        QtMocHelpers::SlotData<void(const FcitxQtFormattedPreeditList &, int, const FcitxQtFormattedPreeditList &, const FcitxQtFormattedPreeditList &, const FcitxQtStringKeyValueList &, int, int, bool, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Int, 9 }, { 0x80000000 | 7, 10 }, { 0x80000000 | 7, 11 },
            { 0x80000000 | 12, 13 }, { QMetaType::Int, 14 }, { QMetaType::Int, 15 }, { QMetaType::Bool, 16 },
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'updatePosition'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sizeHint'
        QtMocHelpers::SlotData<QSize()>(19, 2, QMC::AccessPublic, 0x80000000 | 20),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FcitxCandidateWindow, qt_meta_tag_ZN5fcitx20FcitxCandidateWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject fcitx::FcitxCandidateWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QRasterWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx20FcitxCandidateWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx20FcitxCandidateWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5fcitx20FcitxCandidateWindowE_t>.metaTypes,
    nullptr
} };

void fcitx::FcitxCandidateWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FcitxCandidateWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->candidateSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->prevClicked(); break;
        case 2: _t->nextClicked(); break;
        case 3: _t->updateClientSideUI((*reinterpret_cast<std::add_pointer_t<FcitxQtFormattedPreeditList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<FcitxQtFormattedPreeditList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<FcitxQtFormattedPreeditList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<FcitxQtStringKeyValueList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[9]))); break;
        case 4: _t->updatePosition(); break;
        case 5: { QSize _r = _t->sizeHint();
            if (_a[0]) *reinterpret_cast<QSize*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FcitxCandidateWindow::*)(int )>(_a, &FcitxCandidateWindow::candidateSelected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FcitxCandidateWindow::*)()>(_a, &FcitxCandidateWindow::prevClicked, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FcitxCandidateWindow::*)()>(_a, &FcitxCandidateWindow::nextClicked, 2))
            return;
    }
}

const QMetaObject *fcitx::FcitxCandidateWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::FcitxCandidateWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx20FcitxCandidateWindowE_t>.strings))
        return static_cast<void*>(this);
    return QRasterWindow::qt_metacast(_clname);
}

int fcitx::FcitxCandidateWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QRasterWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void fcitx::FcitxCandidateWindow::candidateSelected(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void fcitx::FcitxCandidateWindow::prevClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void fcitx::FcitxCandidateWindow::nextClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
