/****************************************************************************
** Meta object code from reading C++ file 'qfcitxplatforminputcontext.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../qfcitxplatforminputcontext.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QPointer>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qfcitxplatforminputcontext.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_fcitx__ProcessKeyWatcher_t {
    QByteArrayData data[1];
    char stringdata0[25];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_fcitx__ProcessKeyWatcher_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_fcitx__ProcessKeyWatcher_t qt_meta_stringdata_fcitx__ProcessKeyWatcher = {
    {
QT_MOC_LITERAL(0, 0, 24) // "fcitx::ProcessKeyWatcher"

    },
    "fcitx::ProcessKeyWatcher"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_fcitx__ProcessKeyWatcher[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void fcitx::ProcessKeyWatcher::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject fcitx::ProcessKeyWatcher::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusPendingCallWatcher::staticMetaObject>(),
    qt_meta_stringdata_fcitx__ProcessKeyWatcher.data,
    qt_meta_data_fcitx__ProcessKeyWatcher,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *fcitx::ProcessKeyWatcher::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::ProcessKeyWatcher::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_fcitx__ProcessKeyWatcher.stringdata0))
        return static_cast<void*>(this);
    return QDBusPendingCallWatcher::qt_metacast(_clname);
}

int fcitx::ProcessKeyWatcher::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusPendingCallWatcher::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_fcitx__QFcitxPlatformInputContext_t {
    QByteArrayData data[42];
    char stringdata0[547];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_fcitx__QFcitxPlatformInputContext_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_fcitx__QFcitxPlatformInputContext_t qt_meta_stringdata_fcitx__QFcitxPlatformInputContext = {
    {
QT_MOC_LITERAL(0, 0, 33), // "fcitx::QFcitxPlatformInputCon..."
QT_MOC_LITERAL(1, 34, 17), // "cursorRectChanged"
QT_MOC_LITERAL(2, 52, 0), // ""
QT_MOC_LITERAL(3, 53, 12), // "commitString"
QT_MOC_LITERAL(4, 66, 3), // "str"
QT_MOC_LITERAL(5, 70, 22), // "updateFormattedPreedit"
QT_MOC_LITERAL(6, 93, 27), // "FcitxQtFormattedPreeditList"
QT_MOC_LITERAL(7, 121, 11), // "preeditList"
QT_MOC_LITERAL(8, 133, 9), // "cursorPos"
QT_MOC_LITERAL(9, 143, 21), // "deleteSurroundingText"
QT_MOC_LITERAL(10, 165, 6), // "offset"
QT_MOC_LITERAL(11, 172, 5), // "nchar"
QT_MOC_LITERAL(12, 178, 10), // "forwardKey"
QT_MOC_LITERAL(13, 189, 6), // "keyval"
QT_MOC_LITERAL(14, 196, 5), // "state"
QT_MOC_LITERAL(15, 202, 4), // "type"
QT_MOC_LITERAL(16, 207, 26), // "createInputContextFinished"
QT_MOC_LITERAL(17, 234, 4), // "uuid"
QT_MOC_LITERAL(18, 239, 7), // "cleanUp"
QT_MOC_LITERAL(19, 247, 15), // "windowDestroyed"
QT_MOC_LITERAL(20, 263, 6), // "object"
QT_MOC_LITERAL(21, 270, 15), // "updateCurrentIM"
QT_MOC_LITERAL(22, 286, 4), // "name"
QT_MOC_LITERAL(23, 291, 10), // "uniqueName"
QT_MOC_LITERAL(24, 302, 8), // "langCode"
QT_MOC_LITERAL(25, 311, 18), // "updateClientSideUI"
QT_MOC_LITERAL(26, 330, 7), // "preedit"
QT_MOC_LITERAL(27, 338, 9), // "cursorpos"
QT_MOC_LITERAL(28, 348, 5), // "auxUp"
QT_MOC_LITERAL(29, 354, 7), // "auxDown"
QT_MOC_LITERAL(30, 362, 25), // "FcitxQtStringKeyValueList"
QT_MOC_LITERAL(31, 388, 10), // "candidates"
QT_MOC_LITERAL(32, 399, 14), // "candidateIndex"
QT_MOC_LITERAL(33, 414, 10), // "layoutHint"
QT_MOC_LITERAL(34, 425, 7), // "hasPrev"
QT_MOC_LITERAL(35, 433, 7), // "hasNext"
QT_MOC_LITERAL(36, 441, 18), // "serverSideFocusOut"
QT_MOC_LITERAL(37, 460, 13), // "commitPreedit"
QT_MOC_LITERAL(38, 474, 17), // "QPointer<QObject>"
QT_MOC_LITERAL(39, 492, 5), // "input"
QT_MOC_LITERAL(40, 498, 23), // "processKeyEventFinished"
QT_MOC_LITERAL(41, 522, 24) // "QDBusPendingCallWatcher*"

    },
    "fcitx::QFcitxPlatformInputContext\0"
    "cursorRectChanged\0\0commitString\0str\0"
    "updateFormattedPreedit\0"
    "FcitxQtFormattedPreeditList\0preeditList\0"
    "cursorPos\0deleteSurroundingText\0offset\0"
    "nchar\0forwardKey\0keyval\0state\0type\0"
    "createInputContextFinished\0uuid\0cleanUp\0"
    "windowDestroyed\0object\0updateCurrentIM\0"
    "name\0uniqueName\0langCode\0updateClientSideUI\0"
    "preedit\0cursorpos\0auxUp\0auxDown\0"
    "FcitxQtStringKeyValueList\0candidates\0"
    "candidateIndex\0layoutHint\0hasPrev\0"
    "hasNext\0serverSideFocusOut\0commitPreedit\0"
    "QPointer<QObject>\0input\0processKeyEventFinished\0"
    "QDBusPendingCallWatcher*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_fcitx__QFcitxPlatformInputContext[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   84,    2, 0x0a /* Public */,
       3,    1,   85,    2, 0x0a /* Public */,
       5,    2,   88,    2, 0x0a /* Public */,
       9,    2,   93,    2, 0x0a /* Public */,
      12,    3,   98,    2, 0x0a /* Public */,
      16,    1,  105,    2, 0x0a /* Public */,
      18,    0,  108,    2, 0x0a /* Public */,
      19,    1,  109,    2, 0x0a /* Public */,
      21,    3,  112,    2, 0x0a /* Public */,
      25,    9,  119,    2, 0x0a /* Public */,
      36,    0,  138,    2, 0x0a /* Public */,
      37,    1,  139,    2, 0x0a /* Public */,
      37,    0,  142,    2, 0x2a /* Public | MethodCloned */,
      40,    1,  143,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void, 0x80000000 | 6, QMetaType::Int,    7,    8,
    QMetaType::Void, QMetaType::Int, QMetaType::UInt,   10,   11,
    QMetaType::Void, QMetaType::UInt, QMetaType::UInt, QMetaType::Bool,   13,   14,   15,
    QMetaType::Void, QMetaType::QByteArray,   17,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QObjectStar,   20,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,   22,   23,   24,
    QMetaType::Void, 0x80000000 | 6, QMetaType::Int, 0x80000000 | 6, 0x80000000 | 6, 0x80000000 | 30, QMetaType::Int, QMetaType::Int, QMetaType::Bool, QMetaType::Bool,   26,   27,   28,   29,   31,   32,   33,   34,   35,
    QMetaType::Void,
    QMetaType::Bool, 0x80000000 | 38,   39,
    QMetaType::Bool,
    QMetaType::Void, 0x80000000 | 41,    2,

       0        // eod
};

void fcitx::QFcitxPlatformInputContext::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QFcitxPlatformInputContext *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->cursorRectChanged(); break;
        case 1: _t->commitString((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->updateFormattedPreedit((*reinterpret_cast< const FcitxQtFormattedPreeditList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->deleteSurroundingText((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 4: _t->forwardKey((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 5: _t->createInputContextFinished((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 6: _t->cleanUp(); break;
        case 7: _t->windowDestroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 8: _t->updateCurrentIM((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 9: _t->updateClientSideUI((*reinterpret_cast< const FcitxQtFormattedPreeditList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const FcitxQtFormattedPreeditList(*)>(_a[3])),(*reinterpret_cast< const FcitxQtFormattedPreeditList(*)>(_a[4])),(*reinterpret_cast< const FcitxQtStringKeyValueList(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7])),(*reinterpret_cast< bool(*)>(_a[8])),(*reinterpret_cast< bool(*)>(_a[9]))); break;
        case 10: _t->serverSideFocusOut(); break;
        case 11: { bool _r = _t->commitPreedit((*reinterpret_cast< QPointer<QObject>(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->commitPreedit();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->processKeyEventFinished((*reinterpret_cast< QDBusPendingCallWatcher*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QPointer<QObject> >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject fcitx::QFcitxPlatformInputContext::staticMetaObject = { {
    QMetaObject::SuperData::link<QPlatformInputContext::staticMetaObject>(),
    qt_meta_stringdata_fcitx__QFcitxPlatformInputContext.data,
    qt_meta_data_fcitx__QFcitxPlatformInputContext,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *fcitx::QFcitxPlatformInputContext::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::QFcitxPlatformInputContext::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_fcitx__QFcitxPlatformInputContext.stringdata0))
        return static_cast<void*>(this);
    return QPlatformInputContext::qt_metacast(_clname);
}

int fcitx::QFcitxPlatformInputContext::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QPlatformInputContext::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
