/****************************************************************************
** Meta object code from reading C++ file 'fcitxqtkeysequencewidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../fcitxqtkeysequencewidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fcitxqtkeysequencewidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_fcitx__FcitxQtKeySequenceWidget_t {
    QByteArrayData data[13];
    char stringdata0[214];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_fcitx__FcitxQtKeySequenceWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_fcitx__FcitxQtKeySequenceWidget_t qt_meta_stringdata_fcitx__FcitxQtKeySequenceWidget = {
    {
QT_MOC_LITERAL(0, 0, 31), // "fcitx::FcitxQtKeySequenceWidget"
QT_MOC_LITERAL(1, 32, 18), // "keySequenceChanged"
QT_MOC_LITERAL(2, 51, 0), // ""
QT_MOC_LITERAL(3, 52, 10), // "QList<Key>"
QT_MOC_LITERAL(4, 63, 3), // "seq"
QT_MOC_LITERAL(5, 67, 18), // "captureKeySequence"
QT_MOC_LITERAL(6, 86, 14), // "setKeySequence"
QT_MOC_LITERAL(7, 101, 16), // "clearKeySequence"
QT_MOC_LITERAL(8, 118, 24), // "multiKeyShortcutsAllowed"
QT_MOC_LITERAL(9, 143, 19), // "modifierlessAllowed"
QT_MOC_LITERAL(10, 163, 15), // "modifierAllowed"
QT_MOC_LITERAL(11, 179, 14), // "keycodeAllowed"
QT_MOC_LITERAL(12, 194, 19) // "modifierOnlyAllowed"

    },
    "fcitx::FcitxQtKeySequenceWidget\0"
    "keySequenceChanged\0\0QList<Key>\0seq\0"
    "captureKeySequence\0setKeySequence\0"
    "clearKeySequence\0multiKeyShortcutsAllowed\0"
    "modifierlessAllowed\0modifierAllowed\0"
    "keycodeAllowed\0modifierOnlyAllowed"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_fcitx__FcitxQtKeySequenceWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       5,   42, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    0,   37,    2, 0x0a /* Public */,
       6,    1,   38,    2, 0x0a /* Public */,
       7,    0,   41,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,

 // properties: name, type, flags
       8, QMetaType::Bool, 0x00095103,
       9, QMetaType::Bool, 0x00095103,
      10, QMetaType::Bool, 0x00095103,
      11, QMetaType::Bool, 0x00095103,
      12, QMetaType::Bool, 0x00095103,

       0        // eod
};

void fcitx::FcitxQtKeySequenceWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<FcitxQtKeySequenceWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->keySequenceChanged((*reinterpret_cast< const QList<Key>(*)>(_a[1]))); break;
        case 1: _t->captureKeySequence(); break;
        case 2: _t->setKeySequence((*reinterpret_cast< const QList<Key>(*)>(_a[1]))); break;
        case 3: _t->clearKeySequence(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (FcitxQtKeySequenceWidget::*)(const QList<Key> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtKeySequenceWidget::keySequenceChanged)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<FcitxQtKeySequenceWidget *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->multiKeyShortcutsAllowed(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->isModifierlessAllowed(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->isModifierAllowed(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->isKeycodeAllowed(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->isModifierOnlyAllowed(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<FcitxQtKeySequenceWidget *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMultiKeyShortcutsAllowed(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setModifierlessAllowed(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setModifierAllowed(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setKeycodeAllowed(*reinterpret_cast< bool*>(_v)); break;
        case 4: _t->setModifierOnlyAllowed(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject fcitx::FcitxQtKeySequenceWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_fcitx__FcitxQtKeySequenceWidget.data,
    qt_meta_data_fcitx__FcitxQtKeySequenceWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *fcitx::FcitxQtKeySequenceWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::FcitxQtKeySequenceWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_fcitx__FcitxQtKeySequenceWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int fcitx::FcitxQtKeySequenceWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 5;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void fcitx::FcitxQtKeySequenceWidget::keySequenceChanged(const QList<Key> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
