/****************************************************************************
** Meta object code from reading C++ file 'fcitxqtinputcontextproxyimpl.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../fcitxqtinputcontextproxyimpl.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fcitxqtinputcontextproxyimpl.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5fcitx28FcitxQtInputContextProxyImplE_t {};
} // unnamed namespace

template <> constexpr inline auto fcitx::FcitxQtInputContextProxyImpl::qt_create_metaobjectdata<qt_meta_tag_ZN5fcitx28FcitxQtInputContextProxyImplE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "fcitx::FcitxQtInputContextProxyImpl",
        "CommitString",
        "",
        "str",
        "CurrentIM",
        "name",
        "uniqueName",
        "langCode",
        "DeleteSurroundingText",
        "offset",
        "nchar",
        "ForwardKey",
        "keyval",
        "state",
        "type",
        "NotifyFocusOut",
        "UpdateClientSideUI",
        "FcitxQtFormattedPreeditList",
        "preedit",
        "cursorpos",
        "auxUp",
        "auxDown",
        "FcitxQtStringKeyValueList",
        "candidates",
        "candidateIndex",
        "layoutHint",
        "hasPrev",
        "hasNext",
        "UpdateFormattedPreedit",
        "VirtualKeyboardVisibilityChanged",
        "visible",
        "DestroyIC",
        "QDBusPendingReply<>",
        "FocusIn",
        "FocusOut",
        "HideVirtualKeyboard",
        "InvokeAction",
        "action",
        "cursor",
        "IsVirtualKeyboardVisible",
        "QDBusPendingReply<bool>",
        "NextPage",
        "PrevPage",
        "ProcessKeyEvent",
        "keycode",
        "time",
        "Reset",
        "SelectCandidate",
        "index",
        "SetCapability",
        "caps",
        "SetCursorRect",
        "x",
        "y",
        "w",
        "h",
        "SetCursorRectV2",
        "scale",
        "SetSupportedCapability",
        "SetSurroundingText",
        "text",
        "anchor",
        "SetSurroundingTextPosition",
        "ShowVirtualKeyboard"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'CommitString'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'CurrentIM'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'DeleteSurroundingText'
        QtMocHelpers::SignalData<void(int, unsigned int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 }, { QMetaType::UInt, 10 },
        }}),
        // Signal 'ForwardKey'
        QtMocHelpers::SignalData<void(unsigned int, unsigned int, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 12 }, { QMetaType::UInt, 13 }, { QMetaType::Bool, 14 },
        }}),
        // Signal 'NotifyFocusOut'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UpdateClientSideUI'
        QtMocHelpers::SignalData<void(FcitxQtFormattedPreeditList, int, FcitxQtFormattedPreeditList, FcitxQtFormattedPreeditList, FcitxQtStringKeyValueList, int, int, bool, bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { QMetaType::Int, 19 }, { 0x80000000 | 17, 20 }, { 0x80000000 | 17, 21 },
            { 0x80000000 | 22, 23 }, { QMetaType::Int, 24 }, { QMetaType::Int, 25 }, { QMetaType::Bool, 26 },
            { QMetaType::Bool, 27 },
        }}),
        // Signal 'UpdateFormattedPreedit'
        QtMocHelpers::SignalData<void(FcitxQtFormattedPreeditList, int)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 3 }, { QMetaType::Int, 19 },
        }}),
        // Signal 'VirtualKeyboardVisibilityChanged'
        QtMocHelpers::SignalData<void(bool)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'DestroyIC'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(31, 2, QMC::AccessPublic, 0x80000000 | 32),
        // Slot 'FocusIn'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(33, 2, QMC::AccessPublic, 0x80000000 | 32),
        // Slot 'FocusOut'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(34, 2, QMC::AccessPublic, 0x80000000 | 32),
        // Slot 'HideVirtualKeyboard'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(35, 2, QMC::AccessPublic, 0x80000000 | 32),
        // Slot 'InvokeAction'
        QtMocHelpers::SlotData<QDBusPendingReply<>(unsigned int, int)>(36, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::UInt, 37 }, { QMetaType::Int, 38 },
        }}),
        // Slot 'IsVirtualKeyboardVisible'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(39, 2, QMC::AccessPublic, 0x80000000 | 40),
        // Slot 'NextPage'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(41, 2, QMC::AccessPublic, 0x80000000 | 32),
        // Slot 'PrevPage'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(42, 2, QMC::AccessPublic, 0x80000000 | 32),
        // Slot 'ProcessKeyEvent'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(unsigned int, unsigned int, unsigned int, bool, unsigned int)>(43, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::UInt, 12 }, { QMetaType::UInt, 44 }, { QMetaType::UInt, 13 }, { QMetaType::Bool, 14 },
            { QMetaType::UInt, 45 },
        }}),
        // Slot 'Reset'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(46, 2, QMC::AccessPublic, 0x80000000 | 32),
        // Slot 'SelectCandidate'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(47, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::Int, 48 },
        }}),
        // Slot 'SetCapability'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qulonglong)>(49, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::ULongLong, 50 },
        }}),
        // Slot 'SetCursorRect'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, int, int, int)>(51, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::Int, 52 }, { QMetaType::Int, 53 }, { QMetaType::Int, 54 }, { QMetaType::Int, 55 },
        }}),
        // Slot 'SetCursorRectV2'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, int, int, int, double)>(56, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::Int, 52 }, { QMetaType::Int, 53 }, { QMetaType::Int, 54 }, { QMetaType::Int, 55 },
            { QMetaType::Double, 57 },
        }}),
        // Slot 'SetSupportedCapability'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qulonglong)>(58, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::ULongLong, 50 },
        }}),
        // Slot 'SetSurroundingText'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, unsigned int, unsigned int)>(59, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::QString, 60 }, { QMetaType::UInt, 38 }, { QMetaType::UInt, 61 },
        }}),
        // Slot 'SetSurroundingTextPosition'
        QtMocHelpers::SlotData<QDBusPendingReply<>(unsigned int, unsigned int)>(62, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::UInt, 38 }, { QMetaType::UInt, 61 },
        }}),
        // Slot 'ShowVirtualKeyboard'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(63, 2, QMC::AccessPublic, 0x80000000 | 32),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FcitxQtInputContextProxyImpl, qt_meta_tag_ZN5fcitx28FcitxQtInputContextProxyImplE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject fcitx::FcitxQtInputContextProxyImpl::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx28FcitxQtInputContextProxyImplE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx28FcitxQtInputContextProxyImplE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5fcitx28FcitxQtInputContextProxyImplE_t>.metaTypes,
    nullptr
} };

void fcitx::FcitxQtInputContextProxyImpl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FcitxQtInputContextProxyImpl *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->CommitString((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->CurrentIM((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->DeleteSurroundingText((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 3: _t->ForwardKey((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 4: _t->NotifyFocusOut(); break;
        case 5: _t->UpdateClientSideUI((*reinterpret_cast<std::add_pointer_t<FcitxQtFormattedPreeditList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<FcitxQtFormattedPreeditList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<FcitxQtFormattedPreeditList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<FcitxQtStringKeyValueList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[9]))); break;
        case 6: _t->UpdateFormattedPreedit((*reinterpret_cast<std::add_pointer_t<FcitxQtFormattedPreeditList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->VirtualKeyboardVisibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: { QDBusPendingReply<> _r = _t->DestroyIC();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->FocusIn();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->FocusOut();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->HideVirtualKeyboard();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->InvokeAction((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<bool> _r = _t->IsVirtualKeyboardVisible();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<> _r = _t->NextPage();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<> _r = _t->PrevPage();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<bool> _r = _t->ProcessKeyEvent((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->Reset();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->SelectCandidate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->SetCapability((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<> _r = _t->SetCursorRect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<> _r = _t->SetCursorRectV2((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->SetSupportedCapability((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<> _r = _t->SetSurroundingText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->SetSurroundingTextPosition((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<> _r = _t->ShowVirtualKeyboard();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FcitxQtInputContextProxyImpl::*)(const QString & )>(_a, &FcitxQtInputContextProxyImpl::CommitString, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FcitxQtInputContextProxyImpl::*)(const QString & , const QString & , const QString & )>(_a, &FcitxQtInputContextProxyImpl::CurrentIM, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FcitxQtInputContextProxyImpl::*)(int , unsigned int )>(_a, &FcitxQtInputContextProxyImpl::DeleteSurroundingText, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FcitxQtInputContextProxyImpl::*)(unsigned int , unsigned int , bool )>(_a, &FcitxQtInputContextProxyImpl::ForwardKey, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FcitxQtInputContextProxyImpl::*)()>(_a, &FcitxQtInputContextProxyImpl::NotifyFocusOut, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FcitxQtInputContextProxyImpl::*)(FcitxQtFormattedPreeditList , int , FcitxQtFormattedPreeditList , FcitxQtFormattedPreeditList , FcitxQtStringKeyValueList , int , int , bool , bool )>(_a, &FcitxQtInputContextProxyImpl::UpdateClientSideUI, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FcitxQtInputContextProxyImpl::*)(FcitxQtFormattedPreeditList , int )>(_a, &FcitxQtInputContextProxyImpl::UpdateFormattedPreedit, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FcitxQtInputContextProxyImpl::*)(bool )>(_a, &FcitxQtInputContextProxyImpl::VirtualKeyboardVisibilityChanged, 7))
            return;
    }
}

const QMetaObject *fcitx::FcitxQtInputContextProxyImpl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::FcitxQtInputContextProxyImpl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx28FcitxQtInputContextProxyImplE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int fcitx::FcitxQtInputContextProxyImpl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void fcitx::FcitxQtInputContextProxyImpl::CommitString(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void fcitx::FcitxQtInputContextProxyImpl::CurrentIM(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void fcitx::FcitxQtInputContextProxyImpl::DeleteSurroundingText(int _t1, unsigned int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void fcitx::FcitxQtInputContextProxyImpl::ForwardKey(unsigned int _t1, unsigned int _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void fcitx::FcitxQtInputContextProxyImpl::NotifyFocusOut()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void fcitx::FcitxQtInputContextProxyImpl::UpdateClientSideUI(FcitxQtFormattedPreeditList _t1, int _t2, FcitxQtFormattedPreeditList _t3, FcitxQtFormattedPreeditList _t4, FcitxQtStringKeyValueList _t5, int _t6, int _t7, bool _t8, bool _t9)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7, _t8, _t9);
}

// SIGNAL 6
void fcitx::FcitxQtInputContextProxyImpl::UpdateFormattedPreedit(FcitxQtFormattedPreeditList _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void fcitx::FcitxQtInputContextProxyImpl::VirtualKeyboardVisibilityChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
