/****************************************************************************
** Meta object code from reading C++ file 'qfcitxplatforminputcontext.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../qfcitxplatforminputcontext.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qfcitxplatforminputcontext.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5fcitx17ProcessKeyWatcherE_t {};
} // unnamed namespace

template <> constexpr inline auto fcitx::ProcessKeyWatcher::qt_create_metaobjectdata<qt_meta_tag_ZN5fcitx17ProcessKeyWatcherE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "fcitx::ProcessKeyWatcher"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProcessKeyWatcher, qt_meta_tag_ZN5fcitx17ProcessKeyWatcherE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject fcitx::ProcessKeyWatcher::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusPendingCallWatcher::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx17ProcessKeyWatcherE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx17ProcessKeyWatcherE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5fcitx17ProcessKeyWatcherE_t>.metaTypes,
    nullptr
} };

void fcitx::ProcessKeyWatcher::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProcessKeyWatcher *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *fcitx::ProcessKeyWatcher::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::ProcessKeyWatcher::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx17ProcessKeyWatcherE_t>.strings))
        return static_cast<void*>(this);
    return QDBusPendingCallWatcher::qt_metacast(_clname);
}

int fcitx::ProcessKeyWatcher::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusPendingCallWatcher::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN5fcitx26QFcitxPlatformInputContextE_t {};
} // unnamed namespace

template <> constexpr inline auto fcitx::QFcitxPlatformInputContext::qt_create_metaobjectdata<qt_meta_tag_ZN5fcitx26QFcitxPlatformInputContextE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "fcitx::QFcitxPlatformInputContext",
        "cursorRectChanged",
        "",
        "commitString",
        "str",
        "updateFormattedPreedit",
        "FcitxQtFormattedPreeditList",
        "preeditList",
        "cursorPos",
        "deleteSurroundingText",
        "offset",
        "nchar",
        "forwardKey",
        "keyval",
        "state",
        "type",
        "createInputContextFinished",
        "uuid",
        "cleanUp",
        "windowDestroyed",
        "object",
        "updateCurrentIM",
        "name",
        "uniqueName",
        "langCode",
        "updateClientSideUI",
        "preedit",
        "cursorpos",
        "auxUp",
        "auxDown",
        "FcitxQtStringKeyValueList",
        "candidates",
        "candidateIndex",
        "layoutHint",
        "hasPrev",
        "hasNext",
        "serverSideFocusOut",
        "commitPreedit",
        "QPointer<QObject>",
        "input",
        "processKeyEventFinished",
        "QDBusPendingCallWatcher*"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'cursorRectChanged'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'commitString'
        QtMocHelpers::SlotData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'updateFormattedPreedit'
        QtMocHelpers::SlotData<void(const FcitxQtFormattedPreeditList &, int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::Int, 8 },
        }}),
        // Slot 'deleteSurroundingText'
        QtMocHelpers::SlotData<void(int, unsigned int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 }, { QMetaType::UInt, 11 },
        }}),
        // Slot 'forwardKey'
        QtMocHelpers::SlotData<void(unsigned int, unsigned int, bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 13 }, { QMetaType::UInt, 14 }, { QMetaType::Bool, 15 },
        }}),
        // Slot 'createInputContextFinished'
        QtMocHelpers::SlotData<void(const QByteArray &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 17 },
        }}),
        // Slot 'cleanUp'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'windowDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 20 },
        }}),
        // Slot 'updateCurrentIM'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 }, { QMetaType::QString, 23 }, { QMetaType::QString, 24 },
        }}),
        // Slot 'updateClientSideUI'
        QtMocHelpers::SlotData<void(const FcitxQtFormattedPreeditList &, int, const FcitxQtFormattedPreeditList &, const FcitxQtFormattedPreeditList &, const FcitxQtStringKeyValueList &, int, int, bool, bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 26 }, { QMetaType::Int, 27 }, { 0x80000000 | 6, 28 }, { 0x80000000 | 6, 29 },
            { 0x80000000 | 30, 31 }, { QMetaType::Int, 32 }, { QMetaType::Int, 33 }, { QMetaType::Bool, 34 },
            { QMetaType::Bool, 35 },
        }}),
        // Slot 'serverSideFocusOut'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'commitPreedit'
        QtMocHelpers::SlotData<bool(QPointer<QObject>)>(37, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Slot 'commitPreedit'
        QtMocHelpers::SlotData<bool()>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'processKeyEventFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 41, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QFcitxPlatformInputContext, qt_meta_tag_ZN5fcitx26QFcitxPlatformInputContextE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject fcitx::QFcitxPlatformInputContext::staticMetaObject = { {
    QMetaObject::SuperData::link<QPlatformInputContext::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx26QFcitxPlatformInputContextE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx26QFcitxPlatformInputContextE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5fcitx26QFcitxPlatformInputContextE_t>.metaTypes,
    nullptr
} };

void fcitx::QFcitxPlatformInputContext::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QFcitxPlatformInputContext *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->cursorRectChanged(); break;
        case 1: _t->commitString((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->updateFormattedPreedit((*reinterpret_cast<std::add_pointer_t<FcitxQtFormattedPreeditList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->deleteSurroundingText((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 4: _t->forwardKey((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 5: _t->createInputContextFinished((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 6: _t->cleanUp(); break;
        case 7: _t->windowDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 8: _t->updateCurrentIM((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 9: _t->updateClientSideUI((*reinterpret_cast<std::add_pointer_t<FcitxQtFormattedPreeditList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<FcitxQtFormattedPreeditList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<FcitxQtFormattedPreeditList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<FcitxQtStringKeyValueList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[9]))); break;
        case 10: _t->serverSideFocusOut(); break;
        case 11: { bool _r = _t->commitPreedit((*reinterpret_cast<std::add_pointer_t<QPointer<QObject>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->commitPreedit();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->processKeyEventFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QPointer<QObject> >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *fcitx::QFcitxPlatformInputContext::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::QFcitxPlatformInputContext::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx26QFcitxPlatformInputContextE_t>.strings))
        return static_cast<void*>(this);
    return QPlatformInputContext::qt_metacast(_clname);
}

int fcitx::QFcitxPlatformInputContext::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QPlatformInputContext::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
