/****************************************************************************
** Meta object code from reading C++ file 'fcitxcandidatewindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../fcitxcandidatewindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fcitxcandidatewindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_fcitx__FcitxCandidateWindow_t {
    QByteArrayData data[20];
    char stringdata0[255];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_fcitx__FcitxCandidateWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_fcitx__FcitxCandidateWindow_t qt_meta_stringdata_fcitx__FcitxCandidateWindow = {
    {
QT_MOC_LITERAL(0, 0, 27), // "fcitx::FcitxCandidateWindow"
QT_MOC_LITERAL(1, 28, 17), // "candidateSelected"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 1), // "i"
QT_MOC_LITERAL(4, 49, 11), // "prevClicked"
QT_MOC_LITERAL(5, 61, 11), // "nextClicked"
QT_MOC_LITERAL(6, 73, 18), // "updateClientSideUI"
QT_MOC_LITERAL(7, 92, 27), // "FcitxQtFormattedPreeditList"
QT_MOC_LITERAL(8, 120, 7), // "preedit"
QT_MOC_LITERAL(9, 128, 9), // "cursorpos"
QT_MOC_LITERAL(10, 138, 5), // "auxUp"
QT_MOC_LITERAL(11, 144, 7), // "auxDown"
QT_MOC_LITERAL(12, 152, 25), // "FcitxQtStringKeyValueList"
QT_MOC_LITERAL(13, 178, 10), // "candidates"
QT_MOC_LITERAL(14, 189, 14), // "candidateIndex"
QT_MOC_LITERAL(15, 204, 10), // "layoutHint"
QT_MOC_LITERAL(16, 215, 7), // "hasPrev"
QT_MOC_LITERAL(17, 223, 7), // "hasNext"
QT_MOC_LITERAL(18, 231, 14), // "updatePosition"
QT_MOC_LITERAL(19, 246, 8) // "sizeHint"

    },
    "fcitx::FcitxCandidateWindow\0"
    "candidateSelected\0\0i\0prevClicked\0"
    "nextClicked\0updateClientSideUI\0"
    "FcitxQtFormattedPreeditList\0preedit\0"
    "cursorpos\0auxUp\0auxDown\0"
    "FcitxQtStringKeyValueList\0candidates\0"
    "candidateIndex\0layoutHint\0hasPrev\0"
    "hasNext\0updatePosition\0sizeHint"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_fcitx__FcitxCandidateWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,
       4,    0,   47,    2, 0x06 /* Public */,
       5,    0,   48,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    9,   49,    2, 0x0a /* Public */,
      18,    0,   68,    2, 0x0a /* Public */,
      19,    0,   69,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 7, QMetaType::Int, 0x80000000 | 7, 0x80000000 | 7, 0x80000000 | 12, QMetaType::Int, QMetaType::Int, QMetaType::Bool, QMetaType::Bool,    8,    9,   10,   11,   13,   14,   15,   16,   17,
    QMetaType::Void,
    QMetaType::QSize,

       0        // eod
};

void fcitx::FcitxCandidateWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<FcitxCandidateWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->candidateSelected((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->prevClicked(); break;
        case 2: _t->nextClicked(); break;
        case 3: _t->updateClientSideUI((*reinterpret_cast< const FcitxQtFormattedPreeditList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const FcitxQtFormattedPreeditList(*)>(_a[3])),(*reinterpret_cast< const FcitxQtFormattedPreeditList(*)>(_a[4])),(*reinterpret_cast< const FcitxQtStringKeyValueList(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7])),(*reinterpret_cast< bool(*)>(_a[8])),(*reinterpret_cast< bool(*)>(_a[9]))); break;
        case 4: _t->updatePosition(); break;
        case 5: { QSize _r = _t->sizeHint();
            if (_a[0]) *reinterpret_cast< QSize*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (FcitxCandidateWindow::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxCandidateWindow::candidateSelected)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (FcitxCandidateWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxCandidateWindow::prevClicked)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (FcitxCandidateWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxCandidateWindow::nextClicked)) {
                *result = 2;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject fcitx::FcitxCandidateWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QRasterWindow::staticMetaObject>(),
    qt_meta_stringdata_fcitx__FcitxCandidateWindow.data,
    qt_meta_data_fcitx__FcitxCandidateWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *fcitx::FcitxCandidateWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::FcitxCandidateWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_fcitx__FcitxCandidateWindow.stringdata0))
        return static_cast<void*>(this);
    return QRasterWindow::qt_metacast(_clname);
}

int fcitx::FcitxCandidateWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QRasterWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void fcitx::FcitxCandidateWindow::candidateSelected(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void fcitx::FcitxCandidateWindow::prevClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void fcitx::FcitxCandidateWindow::nextClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
