/********************************************************************************
** Form generated from reading UI file 'batchdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BATCHDIALOG_H
#define UI_BATCHDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <fcitxqti18nhelper.h>

QT_BEGIN_NAMESPACE

class Ui_BatchDialog
{
public:
    QVBoxLayout *verticalLayout;
    QPlainTextEdit *plainTextEdit;
    QHBoxLayout *horizontalLayout;
    QLabel *iconLabel;
    QLabel *infoLabel;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *BatchDialog)
    {
        if (BatchDialog->objectName().isEmpty())
            BatchDialog->setObjectName("BatchDialog");
        BatchDialog->resize(473, 344);
        verticalLayout = new QVBoxLayout(BatchDialog);
        verticalLayout->setObjectName("verticalLayout");
        plainTextEdit = new QPlainTextEdit(BatchDialog);
        plainTextEdit->setObjectName("plainTextEdit");

        verticalLayout->addWidget(plainTextEdit);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        iconLabel = new QLabel(BatchDialog);
        iconLabel->setObjectName("iconLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(iconLabel->sizePolicy().hasHeightForWidth());
        iconLabel->setSizePolicy(sizePolicy);
        iconLabel->setMinimumSize(QSize(22, 22));
        iconLabel->setMaximumSize(QSize(22, 22));

        horizontalLayout->addWidget(iconLabel);

        infoLabel = new QLabel(BatchDialog);
        infoLabel->setObjectName("infoLabel");

        horizontalLayout->addWidget(infoLabel);


        verticalLayout->addLayout(horizontalLayout);

        buttonBox = new QDialogButtonBox(BatchDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(BatchDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, BatchDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, BatchDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(BatchDialog);
    } // setupUi

    void retranslateUi(QDialog *BatchDialog)
    {
        BatchDialog->setWindowTitle(fcitx::tr2fcitx("Batch editing", nullptr));
        iconLabel->setText(QString());
        infoLabel->setText(fcitx::tr2fcitx("Use <Keyword> <Phrase> format on every line.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class BatchDialog: public Ui_BatchDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BATCHDIALOG_H
