/****************************************************************************
** Meta object code from reading C++ file 'fcitx4inputmethodproxy.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../fcitx4inputmethodproxy.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fcitx4inputmethodproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_fcitx__Fcitx4InputMethodProxy_t {
    QByteArrayData data[14];
    char stringdata0[167];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_fcitx__Fcitx4InputMethodProxy_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_fcitx__Fcitx4InputMethodProxy_t qt_meta_stringdata_fcitx__Fcitx4InputMethodProxy = {
    {
QT_MOC_LITERAL(0, 0, 29), // "fcitx::Fcitx4InputMethodProxy"
QT_MOC_LITERAL(1, 30, 10), // "CreateICv3"
QT_MOC_LITERAL(2, 41, 47), // "QDBusPendingReply<int,bool,ui..."
QT_MOC_LITERAL(3, 89, 0), // ""
QT_MOC_LITERAL(4, 90, 7), // "appname"
QT_MOC_LITERAL(5, 98, 3), // "pid"
QT_MOC_LITERAL(6, 102, 15), // "QDBusReply<int>"
QT_MOC_LITERAL(7, 118, 5), // "bool&"
QT_MOC_LITERAL(8, 124, 6), // "enable"
QT_MOC_LITERAL(9, 131, 5), // "uint&"
QT_MOC_LITERAL(10, 137, 7), // "keyval1"
QT_MOC_LITERAL(11, 145, 6), // "state1"
QT_MOC_LITERAL(12, 152, 7), // "keyval2"
QT_MOC_LITERAL(13, 160, 6) // "state2"

    },
    "fcitx::Fcitx4InputMethodProxy\0CreateICv3\0"
    "QDBusPendingReply<int,bool,uint,uint,uint,uint>\0"
    "\0appname\0pid\0QDBusReply<int>\0bool&\0"
    "enable\0uint&\0keyval1\0state1\0keyval2\0"
    "state2"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_fcitx__Fcitx4InputMethodProxy[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   24,    3, 0x0a /* Public */,
       1,    7,   29,    3, 0x0a /* Public */,

 // slots: parameters
    0x80000000 | 2, QMetaType::QString, QMetaType::Int,    4,    5,
    0x80000000 | 6, QMetaType::QString, QMetaType::Int, 0x80000000 | 7, 0x80000000 | 9, 0x80000000 | 9, 0x80000000 | 9, 0x80000000 | 9,    4,    5,    8,   10,   11,   12,   13,

       0        // eod
};

void fcitx::Fcitx4InputMethodProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Fcitx4InputMethodProxy *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { QDBusPendingReply<int,bool,uint,uint,uint,uint> _r = _t->CreateICv3((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<int,bool,uint,uint,uint,uint>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusReply<int> _r = _t->CreateICv3((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< uint(*)>(_a[4])),(*reinterpret_cast< uint(*)>(_a[5])),(*reinterpret_cast< uint(*)>(_a[6])),(*reinterpret_cast< uint(*)>(_a[7])));
            if (_a[0]) *reinterpret_cast< QDBusReply<int>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject fcitx::Fcitx4InputMethodProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_meta_stringdata_fcitx__Fcitx4InputMethodProxy.data,
    qt_meta_data_fcitx__Fcitx4InputMethodProxy,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *fcitx::Fcitx4InputMethodProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::Fcitx4InputMethodProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_fcitx__Fcitx4InputMethodProxy.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int fcitx::Fcitx4InputMethodProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
