/****************************************************************************
** Meta object code from reading C++ file 'hybridinputcontext.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../hybridinputcontext.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'hybridinputcontext.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5fcitx18HybridInputContextE_t {};
} // unnamed namespace

template <> constexpr inline auto fcitx::HybridInputContext::qt_create_metaobjectdata<qt_meta_tag_ZN5fcitx18HybridInputContextE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "fcitx::HybridInputContext",
        "commitString",
        "",
        "str",
        "currentIM",
        "name",
        "uniqueName",
        "langCode",
        "deleteSurroundingText",
        "offset",
        "nchar",
        "forwardKey",
        "keyval",
        "state",
        "isRelease",
        "updateFormattedPreedit",
        "FcitxQtFormattedPreeditList",
        "cursorpos",
        "updateClientSideUI",
        "preedit",
        "auxUp",
        "auxDown",
        "FcitxQtStringKeyValueList",
        "candidates",
        "candidateIndex",
        "layoutHint",
        "hasPrev",
        "hasNext",
        "inputContextCreated",
        "uuid",
        "notifyFocusOut",
        "virtualKeyboardVisibilityChanged",
        "visible",
        "recheck",
        "doRecheck",
        "skipFcitx5",
        "inputContextCreationFailed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'commitString'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'currentIM'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'deleteSurroundingText'
        QtMocHelpers::SignalData<void(int, unsigned int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 }, { QMetaType::UInt, 10 },
        }}),
        // Signal 'forwardKey'
        QtMocHelpers::SignalData<void(unsigned int, unsigned int, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 12 }, { QMetaType::UInt, 13 }, { QMetaType::Bool, 14 },
        }}),
        // Signal 'updateFormattedPreedit'
        QtMocHelpers::SignalData<void(const FcitxQtFormattedPreeditList &, int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 3 }, { QMetaType::Int, 17 },
        }}),
        // Signal 'updateClientSideUI'
        QtMocHelpers::SignalData<void(const FcitxQtFormattedPreeditList &, int, const FcitxQtFormattedPreeditList &, const FcitxQtFormattedPreeditList &, const FcitxQtStringKeyValueList &, int, int, bool, bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 19 }, { QMetaType::Int, 17 }, { 0x80000000 | 16, 20 }, { 0x80000000 | 16, 21 },
            { 0x80000000 | 22, 23 }, { QMetaType::Int, 24 }, { QMetaType::Int, 25 }, { QMetaType::Bool, 26 },
            { QMetaType::Bool, 27 },
        }}),
        // Signal 'inputContextCreated'
        QtMocHelpers::SignalData<void(const QByteArray &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 29 },
        }}),
        // Signal 'notifyFocusOut'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'virtualKeyboardVisibilityChanged'
        QtMocHelpers::SignalData<void(bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'recheck'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doRecheck'
        QtMocHelpers::SlotData<void(bool)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 35 },
        }}),
        // Slot 'inputContextCreationFailed'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HybridInputContext, qt_meta_tag_ZN5fcitx18HybridInputContextE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject fcitx::HybridInputContext::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx18HybridInputContextE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx18HybridInputContextE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5fcitx18HybridInputContextE_t>.metaTypes,
    nullptr
} };

void fcitx::HybridInputContext::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HybridInputContext *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->commitString((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->currentIM((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->deleteSurroundingText((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 3: _t->forwardKey((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 4: _t->updateFormattedPreedit((*reinterpret_cast<std::add_pointer_t<FcitxQtFormattedPreeditList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->updateClientSideUI((*reinterpret_cast<std::add_pointer_t<FcitxQtFormattedPreeditList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<FcitxQtFormattedPreeditList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<FcitxQtFormattedPreeditList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<FcitxQtStringKeyValueList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[9]))); break;
        case 6: _t->inputContextCreated((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 7: _t->notifyFocusOut(); break;
        case 8: _t->virtualKeyboardVisibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->recheck(); break;
        case 10: _t->doRecheck((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->inputContextCreationFailed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (HybridInputContext::*)(const QString & )>(_a, &HybridInputContext::commitString, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (HybridInputContext::*)(const QString & , const QString & , const QString & )>(_a, &HybridInputContext::currentIM, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (HybridInputContext::*)(int , unsigned int )>(_a, &HybridInputContext::deleteSurroundingText, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (HybridInputContext::*)(unsigned int , unsigned int , bool )>(_a, &HybridInputContext::forwardKey, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (HybridInputContext::*)(const FcitxQtFormattedPreeditList & , int )>(_a, &HybridInputContext::updateFormattedPreedit, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (HybridInputContext::*)(const FcitxQtFormattedPreeditList & , int , const FcitxQtFormattedPreeditList & , const FcitxQtFormattedPreeditList & , const FcitxQtStringKeyValueList & , int , int , bool , bool )>(_a, &HybridInputContext::updateClientSideUI, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (HybridInputContext::*)(const QByteArray & )>(_a, &HybridInputContext::inputContextCreated, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (HybridInputContext::*)()>(_a, &HybridInputContext::notifyFocusOut, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (HybridInputContext::*)(bool )>(_a, &HybridInputContext::virtualKeyboardVisibilityChanged, 8))
            return;
    }
}

const QMetaObject *fcitx::HybridInputContext::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::HybridInputContext::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx18HybridInputContextE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int fcitx::HybridInputContext::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void fcitx::HybridInputContext::commitString(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void fcitx::HybridInputContext::currentIM(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void fcitx::HybridInputContext::deleteSurroundingText(int _t1, unsigned int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void fcitx::HybridInputContext::forwardKey(unsigned int _t1, unsigned int _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void fcitx::HybridInputContext::updateFormattedPreedit(const FcitxQtFormattedPreeditList & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void fcitx::HybridInputContext::updateClientSideUI(const FcitxQtFormattedPreeditList & _t1, int _t2, const FcitxQtFormattedPreeditList & _t3, const FcitxQtFormattedPreeditList & _t4, const FcitxQtStringKeyValueList & _t5, int _t6, int _t7, bool _t8, bool _t9)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7, _t8, _t9);
}

// SIGNAL 6
void fcitx::HybridInputContext::inputContextCreated(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void fcitx::HybridInputContext::notifyFocusOut()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void fcitx::HybridInputContext::virtualKeyboardVisibilityChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
