/****************************************************************************
** Meta object code from reading C++ file 'editor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../editor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'editor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5fcitx10ListEditorE_t {};
} // unnamed namespace

template <> constexpr inline auto fcitx::ListEditor::qt_create_metaobjectdata<qt_meta_tag_ZN5fcitx10ListEditorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "fcitx::ListEditor",
        "batchEditAccepted",
        "",
        "removeFileTriggered",
        "addFileTriggered",
        "refreshListTriggered",
        "changeFile",
        "addWord",
        "batchEditWord",
        "deleteWord",
        "deleteAllWord",
        "itemFocusChanged",
        "addWordAccepted",
        "importData",
        "exportData",
        "importFileSelected",
        "exportFileSelected"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'batchEditAccepted'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeFileTriggered'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addFileTriggered'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refreshListTriggered'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeFile'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'addWord'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'batchEditWord'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteWord'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteAllWord'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'itemFocusChanged'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addWordAccepted'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'importData'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'exportData'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'importFileSelected'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'exportFileSelected'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ListEditor, qt_meta_tag_ZN5fcitx10ListEditorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject fcitx::ListEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<FcitxQtConfigUIWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx10ListEditorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx10ListEditorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5fcitx10ListEditorE_t>.metaTypes,
    nullptr
} };

void fcitx::ListEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ListEditor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->batchEditAccepted(); break;
        case 1: _t->removeFileTriggered(); break;
        case 2: _t->addFileTriggered(); break;
        case 3: _t->refreshListTriggered(); break;
        case 4: _t->changeFile((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->addWord(); break;
        case 6: _t->batchEditWord(); break;
        case 7: _t->deleteWord(); break;
        case 8: _t->deleteAllWord(); break;
        case 9: _t->itemFocusChanged(); break;
        case 10: _t->addWordAccepted(); break;
        case 11: _t->importData(); break;
        case 12: _t->exportData(); break;
        case 13: _t->importFileSelected(); break;
        case 14: _t->exportFileSelected(); break;
        default: ;
        }
    }
}

const QMetaObject *fcitx::ListEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::ListEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx10ListEditorE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::Editor"))
        return static_cast< Ui::Editor*>(this);
    return FcitxQtConfigUIWidget::qt_metacast(_clname);
}

int fcitx::ListEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = FcitxQtConfigUIWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
