/****************************************************************************
** Meta object code from reading C++ file 'fcitxqtcontrollerproxy.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../fcitxqtcontrollerproxy.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fcitxqtcontrollerproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_fcitx__FcitxQtControllerProxy_t {
    QByteArrayData data[67];
    char stringdata0[1294];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_fcitx__FcitxQtControllerProxy_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_fcitx__FcitxQtControllerProxy_t qt_meta_stringdata_fcitx__FcitxQtControllerProxy = {
    {
QT_MOC_LITERAL(0, 0, 29), // "fcitx::FcitxQtControllerProxy"
QT_MOC_LITERAL(1, 30, 24), // "InputMethodGroupsChanged"
QT_MOC_LITERAL(2, 55, 0), // ""
QT_MOC_LITERAL(3, 56, 8), // "Activate"
QT_MOC_LITERAL(4, 65, 19), // "QDBusPendingReply<>"
QT_MOC_LITERAL(5, 85, 19), // "AddInputMethodGroup"
QT_MOC_LITERAL(6, 105, 3), // "in0"
QT_MOC_LITERAL(7, 109, 10), // "AddonForIM"
QT_MOC_LITERAL(8, 120, 26), // "QDBusPendingReply<QString>"
QT_MOC_LITERAL(9, 147, 21), // "AvailableInputMethods"
QT_MOC_LITERAL(10, 169, 46), // "QDBusPendingReply<FcitxQtInpu..."
QT_MOC_LITERAL(11, 216, 24), // "AvailableKeyboardLayouts"
QT_MOC_LITERAL(12, 241, 40), // "QDBusPendingReply<FcitxQtLayo..."
QT_MOC_LITERAL(13, 282, 10), // "CanRestart"
QT_MOC_LITERAL(14, 293, 23), // "QDBusPendingReply<bool>"
QT_MOC_LITERAL(15, 317, 11), // "CheckUpdate"
QT_MOC_LITERAL(16, 329, 9), // "Configure"
QT_MOC_LITERAL(17, 339, 14), // "ConfigureAddon"
QT_MOC_LITERAL(18, 354, 11), // "ConfigureIM"
QT_MOC_LITERAL(19, 366, 18), // "CurrentInputMethod"
QT_MOC_LITERAL(20, 385, 9), // "CurrentUI"
QT_MOC_LITERAL(21, 395, 4), // "Exit"
QT_MOC_LITERAL(22, 400, 24), // "FullInputMethodGroupInfo"
QT_MOC_LITERAL(23, 425, 86), // "QDBusPendingReply<QString,QSt..."
QT_MOC_LITERAL(24, 512, 19), // "QDBusReply<QString>"
QT_MOC_LITERAL(25, 532, 8), // "QString&"
QT_MOC_LITERAL(26, 541, 18), // "defaultInputMethod"
QT_MOC_LITERAL(27, 560, 13), // "defaultLayout"
QT_MOC_LITERAL(28, 574, 12), // "QVariantMap&"
QT_MOC_LITERAL(29, 587, 10), // "properties"
QT_MOC_LITERAL(30, 598, 32), // "FcitxQtFullInputMethodEntryList&"
QT_MOC_LITERAL(31, 631, 20), // "inputMethodEntryList"
QT_MOC_LITERAL(32, 652, 9), // "GetAddons"
QT_MOC_LITERAL(33, 662, 39), // "QDBusPendingReply<FcitxQtAddo..."
QT_MOC_LITERAL(34, 702, 11), // "GetAddonsV2"
QT_MOC_LITERAL(35, 714, 41), // "QDBusPendingReply<FcitxQtAddo..."
QT_MOC_LITERAL(36, 756, 9), // "GetConfig"
QT_MOC_LITERAL(37, 766, 53), // "QDBusPendingReply<QDBusVarian..."
QT_MOC_LITERAL(38, 820, 24), // "QDBusReply<QDBusVariant>"
QT_MOC_LITERAL(39, 845, 22), // "FcitxQtConfigTypeList&"
QT_MOC_LITERAL(40, 868, 4), // "out1"
QT_MOC_LITERAL(41, 873, 20), // "InputMethodGroupInfo"
QT_MOC_LITERAL(42, 894, 52), // "QDBusPendingReply<QString,Fci..."
QT_MOC_LITERAL(43, 947, 26), // "FcitxQtStringKeyValueList&"
QT_MOC_LITERAL(44, 974, 5), // "items"
QT_MOC_LITERAL(45, 980, 17), // "InputMethodGroups"
QT_MOC_LITERAL(46, 998, 30), // "QDBusPendingReply<QStringList>"
QT_MOC_LITERAL(47, 1029, 7), // "Refresh"
QT_MOC_LITERAL(48, 1037, 17), // "ReloadAddonConfig"
QT_MOC_LITERAL(49, 1055, 12), // "ReloadConfig"
QT_MOC_LITERAL(50, 1068, 22), // "RemoveInputMethodGroup"
QT_MOC_LITERAL(51, 1091, 11), // "ResetIMList"
QT_MOC_LITERAL(52, 1103, 7), // "Restart"
QT_MOC_LITERAL(53, 1111, 14), // "SetAddonsState"
QT_MOC_LITERAL(54, 1126, 21), // "FcitxQtAddonStateList"
QT_MOC_LITERAL(55, 1148, 9), // "SetConfig"
QT_MOC_LITERAL(56, 1158, 12), // "QDBusVariant"
QT_MOC_LITERAL(57, 1171, 3), // "in1"
QT_MOC_LITERAL(58, 1175, 12), // "SetCurrentIM"
QT_MOC_LITERAL(59, 1188, 23), // "SetInputMethodGroupInfo"
QT_MOC_LITERAL(60, 1212, 4), // "name"
QT_MOC_LITERAL(61, 1217, 6), // "layout"
QT_MOC_LITERAL(62, 1224, 25), // "FcitxQtStringKeyValueList"
QT_MOC_LITERAL(63, 1250, 7), // "entries"
QT_MOC_LITERAL(64, 1258, 5), // "State"
QT_MOC_LITERAL(65, 1264, 22), // "QDBusPendingReply<int>"
QT_MOC_LITERAL(66, 1287, 6) // "Toggle"

    },
    "fcitx::FcitxQtControllerProxy\0"
    "InputMethodGroupsChanged\0\0Activate\0"
    "QDBusPendingReply<>\0AddInputMethodGroup\0"
    "in0\0AddonForIM\0QDBusPendingReply<QString>\0"
    "AvailableInputMethods\0"
    "QDBusPendingReply<FcitxQtInputMethodEntryList>\0"
    "AvailableKeyboardLayouts\0"
    "QDBusPendingReply<FcitxQtLayoutInfoList>\0"
    "CanRestart\0QDBusPendingReply<bool>\0"
    "CheckUpdate\0Configure\0ConfigureAddon\0"
    "ConfigureIM\0CurrentInputMethod\0CurrentUI\0"
    "Exit\0FullInputMethodGroupInfo\0"
    "QDBusPendingReply<QString,QString,QString,QVariantMap,FcitxQtFullInput"
    "MethodEntryList>\0"
    "QDBusReply<QString>\0QString&\0"
    "defaultInputMethod\0defaultLayout\0"
    "QVariantMap&\0properties\0"
    "FcitxQtFullInputMethodEntryList&\0"
    "inputMethodEntryList\0GetAddons\0"
    "QDBusPendingReply<FcitxQtAddonInfoList>\0"
    "GetAddonsV2\0QDBusPendingReply<FcitxQtAddonInfoV2List>\0"
    "GetConfig\0"
    "QDBusPendingReply<QDBusVariant,FcitxQtConfigTypeList>\0"
    "QDBusReply<QDBusVariant>\0"
    "FcitxQtConfigTypeList&\0out1\0"
    "InputMethodGroupInfo\0"
    "QDBusPendingReply<QString,FcitxQtStringKeyValueList>\0"
    "FcitxQtStringKeyValueList&\0items\0"
    "InputMethodGroups\0QDBusPendingReply<QStringList>\0"
    "Refresh\0ReloadAddonConfig\0ReloadConfig\0"
    "RemoveInputMethodGroup\0ResetIMList\0"
    "Restart\0SetAddonsState\0FcitxQtAddonStateList\0"
    "SetConfig\0QDBusVariant\0in1\0SetCurrentIM\0"
    "SetInputMethodGroupInfo\0name\0layout\0"
    "FcitxQtStringKeyValueList\0entries\0"
    "State\0QDBusPendingReply<int>\0Toggle"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_fcitx__FcitxQtControllerProxy[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      35,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  189,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,  190,    2, 0x0a /* Public */,
       5,    1,  191,    2, 0x0a /* Public */,
       7,    1,  194,    2, 0x0a /* Public */,
       9,    0,  197,    2, 0x0a /* Public */,
      11,    0,  198,    2, 0x0a /* Public */,
      13,    0,  199,    2, 0x0a /* Public */,
      15,    0,  200,    2, 0x0a /* Public */,
      16,    0,  201,    2, 0x0a /* Public */,
      17,    1,  202,    2, 0x0a /* Public */,
      18,    1,  205,    2, 0x0a /* Public */,
      19,    0,  208,    2, 0x0a /* Public */,
      20,    0,  209,    2, 0x0a /* Public */,
      21,    0,  210,    2, 0x0a /* Public */,
      22,    1,  211,    2, 0x0a /* Public */,
      22,    5,  214,    2, 0x0a /* Public */,
      32,    0,  225,    2, 0x0a /* Public */,
      34,    0,  226,    2, 0x0a /* Public */,
      36,    1,  227,    2, 0x0a /* Public */,
      36,    2,  230,    2, 0x0a /* Public */,
      41,    1,  235,    2, 0x0a /* Public */,
      41,    2,  238,    2, 0x0a /* Public */,
      45,    0,  243,    2, 0x0a /* Public */,
      47,    0,  244,    2, 0x0a /* Public */,
      48,    1,  245,    2, 0x0a /* Public */,
      49,    0,  248,    2, 0x0a /* Public */,
      50,    1,  249,    2, 0x0a /* Public */,
      51,    0,  252,    2, 0x0a /* Public */,
      52,    0,  253,    2, 0x0a /* Public */,
      53,    1,  254,    2, 0x0a /* Public */,
      55,    2,  257,    2, 0x0a /* Public */,
      58,    1,  262,    2, 0x0a /* Public */,
      59,    3,  265,    2, 0x0a /* Public */,
      64,    0,  272,    2, 0x0a /* Public */,
      66,    0,  273,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    0x80000000 | 4,
    0x80000000 | 4, QMetaType::QString,    6,
    0x80000000 | 8, QMetaType::QString,    6,
    0x80000000 | 10,
    0x80000000 | 12,
    0x80000000 | 14,
    0x80000000 | 14,
    0x80000000 | 4,
    0x80000000 | 4, QMetaType::QString,    6,
    0x80000000 | 4, QMetaType::QString,    6,
    0x80000000 | 8,
    0x80000000 | 8,
    0x80000000 | 4,
    0x80000000 | 23, QMetaType::QString,    6,
    0x80000000 | 24, QMetaType::QString, 0x80000000 | 25, 0x80000000 | 25, 0x80000000 | 28, 0x80000000 | 30,    6,   26,   27,   29,   31,
    0x80000000 | 33,
    0x80000000 | 35,
    0x80000000 | 37, QMetaType::QString,    6,
    0x80000000 | 38, QMetaType::QString, 0x80000000 | 39,    6,   40,
    0x80000000 | 42, QMetaType::QString,    6,
    0x80000000 | 24, QMetaType::QString, 0x80000000 | 43,    6,   44,
    0x80000000 | 46,
    0x80000000 | 4,
    0x80000000 | 4, QMetaType::QString,    6,
    0x80000000 | 4,
    0x80000000 | 4, QMetaType::QString,    6,
    0x80000000 | 4,
    0x80000000 | 4,
    0x80000000 | 4, 0x80000000 | 54,    6,
    0x80000000 | 4, QMetaType::QString, 0x80000000 | 56,    6,   57,
    0x80000000 | 4, QMetaType::QString,    6,
    0x80000000 | 4, QMetaType::QString, QMetaType::QString, 0x80000000 | 62,   60,   61,   63,
    0x80000000 | 65,
    0x80000000 | 4,

       0        // eod
};

void fcitx::FcitxQtControllerProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<FcitxQtControllerProxy *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->InputMethodGroupsChanged(); break;
        case 1: { QDBusPendingReply<> _r = _t->Activate();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->AddInputMethodGroup((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<QString> _r = _t->AddonForIM((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<FcitxQtInputMethodEntryList> _r = _t->AvailableInputMethods();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<FcitxQtInputMethodEntryList>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<FcitxQtLayoutInfoList> _r = _t->AvailableKeyboardLayouts();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<FcitxQtLayoutInfoList>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<bool> _r = _t->CanRestart();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<bool> _r = _t->CheckUpdate();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->Configure();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->ConfigureAddon((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->ConfigureIM((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<QString> _r = _t->CurrentInputMethod();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<QString> _r = _t->CurrentUI();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<> _r = _t->Exit();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<QString,QString,QString,QVariantMap,FcitxQtFullInputMethodEntryList> _r = _t->FullInputMethodGroupInfo((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QString,QString,QString,QVariantMap,FcitxQtFullInputMethodEntryList>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusReply<QString> _r = _t->FullInputMethodGroupInfo((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3])),(*reinterpret_cast< QVariantMap(*)>(_a[4])),(*reinterpret_cast< FcitxQtFullInputMethodEntryList(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QDBusReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<FcitxQtAddonInfoList> _r = _t->GetAddons();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<FcitxQtAddonInfoList>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<FcitxQtAddonInfoV2List> _r = _t->GetAddonsV2();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<FcitxQtAddonInfoV2List>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<QDBusVariant,FcitxQtConfigTypeList> _r = _t->GetConfig((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QDBusVariant,FcitxQtConfigTypeList>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusReply<QDBusVariant> _r = _t->GetConfig((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< FcitxQtConfigTypeList(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusReply<QDBusVariant>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<QString,FcitxQtStringKeyValueList> _r = _t->InputMethodGroupInfo((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QString,FcitxQtStringKeyValueList>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusReply<QString> _r = _t->InputMethodGroupInfo((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< FcitxQtStringKeyValueList(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<QStringList> _r = _t->InputMethodGroups();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<> _r = _t->Refresh();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->ReloadAddonConfig((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<> _r = _t->ReloadConfig();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<> _r = _t->RemoveInputMethodGroup((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QDBusPendingReply<> _r = _t->ResetIMList();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 28: { QDBusPendingReply<> _r = _t->Restart();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 29: { QDBusPendingReply<> _r = _t->SetAddonsState((*reinterpret_cast< FcitxQtAddonStateList(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 30: { QDBusPendingReply<> _r = _t->SetConfig((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QDBusVariant(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 31: { QDBusPendingReply<> _r = _t->SetCurrentIM((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 32: { QDBusPendingReply<> _r = _t->SetInputMethodGroupInfo((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< FcitxQtStringKeyValueList(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 33: { QDBusPendingReply<int> _r = _t->State();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 34: { QDBusPendingReply<> _r = _t->Toggle();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusVariant >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (FcitxQtControllerProxy::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FcitxQtControllerProxy::InputMethodGroupsChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject fcitx::FcitxQtControllerProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_meta_stringdata_fcitx__FcitxQtControllerProxy.data,
    qt_meta_data_fcitx__FcitxQtControllerProxy,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *fcitx::FcitxQtControllerProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::FcitxQtControllerProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_fcitx__FcitxQtControllerProxy.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int fcitx::FcitxQtControllerProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    return _id;
}

// SIGNAL 0
void fcitx::FcitxQtControllerProxy::InputMethodGroupsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
