/****************************************************************************
** Meta object code from reading C++ file 'hybridinputcontext.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../hybridinputcontext.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'hybridinputcontext.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_fcitx__HybridInputContext_t {
    QByteArrayData data[37];
    char stringdata0[466];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_fcitx__HybridInputContext_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_fcitx__HybridInputContext_t qt_meta_stringdata_fcitx__HybridInputContext = {
    {
QT_MOC_LITERAL(0, 0, 25), // "fcitx::HybridInputContext"
QT_MOC_LITERAL(1, 26, 12), // "commitString"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 3), // "str"
QT_MOC_LITERAL(4, 44, 9), // "currentIM"
QT_MOC_LITERAL(5, 54, 4), // "name"
QT_MOC_LITERAL(6, 59, 10), // "uniqueName"
QT_MOC_LITERAL(7, 70, 8), // "langCode"
QT_MOC_LITERAL(8, 79, 21), // "deleteSurroundingText"
QT_MOC_LITERAL(9, 101, 6), // "offset"
QT_MOC_LITERAL(10, 108, 5), // "nchar"
QT_MOC_LITERAL(11, 114, 10), // "forwardKey"
QT_MOC_LITERAL(12, 125, 6), // "keyval"
QT_MOC_LITERAL(13, 132, 5), // "state"
QT_MOC_LITERAL(14, 138, 9), // "isRelease"
QT_MOC_LITERAL(15, 148, 22), // "updateFormattedPreedit"
QT_MOC_LITERAL(16, 171, 27), // "FcitxQtFormattedPreeditList"
QT_MOC_LITERAL(17, 199, 9), // "cursorpos"
QT_MOC_LITERAL(18, 209, 18), // "updateClientSideUI"
QT_MOC_LITERAL(19, 228, 7), // "preedit"
QT_MOC_LITERAL(20, 236, 5), // "auxUp"
QT_MOC_LITERAL(21, 242, 7), // "auxDown"
QT_MOC_LITERAL(22, 250, 25), // "FcitxQtStringKeyValueList"
QT_MOC_LITERAL(23, 276, 10), // "candidates"
QT_MOC_LITERAL(24, 287, 14), // "candidateIndex"
QT_MOC_LITERAL(25, 302, 10), // "layoutHint"
QT_MOC_LITERAL(26, 313, 7), // "hasPrev"
QT_MOC_LITERAL(27, 321, 7), // "hasNext"
QT_MOC_LITERAL(28, 329, 19), // "inputContextCreated"
QT_MOC_LITERAL(29, 349, 4), // "uuid"
QT_MOC_LITERAL(30, 354, 14), // "notifyFocusOut"
QT_MOC_LITERAL(31, 369, 32), // "virtualKeyboardVisibilityChanged"
QT_MOC_LITERAL(32, 402, 7), // "visible"
QT_MOC_LITERAL(33, 410, 7), // "recheck"
QT_MOC_LITERAL(34, 418, 9), // "doRecheck"
QT_MOC_LITERAL(35, 428, 10), // "skipFcitx5"
QT_MOC_LITERAL(36, 439, 26) // "inputContextCreationFailed"

    },
    "fcitx::HybridInputContext\0commitString\0"
    "\0str\0currentIM\0name\0uniqueName\0langCode\0"
    "deleteSurroundingText\0offset\0nchar\0"
    "forwardKey\0keyval\0state\0isRelease\0"
    "updateFormattedPreedit\0"
    "FcitxQtFormattedPreeditList\0cursorpos\0"
    "updateClientSideUI\0preedit\0auxUp\0"
    "auxDown\0FcitxQtStringKeyValueList\0"
    "candidates\0candidateIndex\0layoutHint\0"
    "hasPrev\0hasNext\0inputContextCreated\0"
    "uuid\0notifyFocusOut\0"
    "virtualKeyboardVisibilityChanged\0"
    "visible\0recheck\0doRecheck\0skipFcitx5\0"
    "inputContextCreationFailed"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_fcitx__HybridInputContext[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x06 /* Public */,
       4,    3,   77,    2, 0x06 /* Public */,
       8,    2,   84,    2, 0x06 /* Public */,
      11,    3,   89,    2, 0x06 /* Public */,
      15,    2,   96,    2, 0x06 /* Public */,
      18,    9,  101,    2, 0x06 /* Public */,
      28,    1,  120,    2, 0x06 /* Public */,
      30,    0,  123,    2, 0x06 /* Public */,
      31,    1,  124,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      33,    0,  127,    2, 0x08 /* Private */,
      34,    1,  128,    2, 0x08 /* Private */,
      36,    0,  131,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,    5,    6,    7,
    QMetaType::Void, QMetaType::Int, QMetaType::UInt,    9,   10,
    QMetaType::Void, QMetaType::UInt, QMetaType::UInt, QMetaType::Bool,   12,   13,   14,
    QMetaType::Void, 0x80000000 | 16, QMetaType::Int,    3,   17,
    QMetaType::Void, 0x80000000 | 16, QMetaType::Int, 0x80000000 | 16, 0x80000000 | 16, 0x80000000 | 22, QMetaType::Int, QMetaType::Int, QMetaType::Bool, QMetaType::Bool,   19,   17,   20,   21,   23,   24,   25,   26,   27,
    QMetaType::Void, QMetaType::QByteArray,   29,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   32,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   35,
    QMetaType::Void,

       0        // eod
};

void fcitx::HybridInputContext::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<HybridInputContext *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->commitString((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->currentIM((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 2: _t->deleteSurroundingText((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 3: _t->forwardKey((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 4: _t->updateFormattedPreedit((*reinterpret_cast< const FcitxQtFormattedPreeditList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 5: _t->updateClientSideUI((*reinterpret_cast< const FcitxQtFormattedPreeditList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const FcitxQtFormattedPreeditList(*)>(_a[3])),(*reinterpret_cast< const FcitxQtFormattedPreeditList(*)>(_a[4])),(*reinterpret_cast< const FcitxQtStringKeyValueList(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7])),(*reinterpret_cast< bool(*)>(_a[8])),(*reinterpret_cast< bool(*)>(_a[9]))); break;
        case 6: _t->inputContextCreated((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 7: _t->notifyFocusOut(); break;
        case 8: _t->virtualKeyboardVisibilityChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->recheck(); break;
        case 10: _t->doRecheck((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->inputContextCreationFailed(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (HybridInputContext::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HybridInputContext::commitString)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (HybridInputContext::*)(const QString & , const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HybridInputContext::currentIM)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (HybridInputContext::*)(int , unsigned int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HybridInputContext::deleteSurroundingText)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (HybridInputContext::*)(unsigned int , unsigned int , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HybridInputContext::forwardKey)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (HybridInputContext::*)(const FcitxQtFormattedPreeditList & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HybridInputContext::updateFormattedPreedit)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (HybridInputContext::*)(const FcitxQtFormattedPreeditList & , int , const FcitxQtFormattedPreeditList & , const FcitxQtFormattedPreeditList & , const FcitxQtStringKeyValueList & , int , int , bool , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HybridInputContext::updateClientSideUI)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (HybridInputContext::*)(const QByteArray & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HybridInputContext::inputContextCreated)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (HybridInputContext::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HybridInputContext::notifyFocusOut)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (HybridInputContext::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HybridInputContext::virtualKeyboardVisibilityChanged)) {
                *result = 8;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject fcitx::HybridInputContext::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_fcitx__HybridInputContext.data,
    qt_meta_data_fcitx__HybridInputContext,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *fcitx::HybridInputContext::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::HybridInputContext::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_fcitx__HybridInputContext.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int fcitx::HybridInputContext::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void fcitx::HybridInputContext::commitString(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void fcitx::HybridInputContext::currentIM(const QString & _t1, const QString & _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void fcitx::HybridInputContext::deleteSurroundingText(int _t1, unsigned int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void fcitx::HybridInputContext::forwardKey(unsigned int _t1, unsigned int _t2, bool _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void fcitx::HybridInputContext::updateFormattedPreedit(const FcitxQtFormattedPreeditList & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void fcitx::HybridInputContext::updateClientSideUI(const FcitxQtFormattedPreeditList & _t1, int _t2, const FcitxQtFormattedPreeditList & _t3, const FcitxQtFormattedPreeditList & _t4, const FcitxQtStringKeyValueList & _t5, int _t6, int _t7, bool _t8, bool _t9)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t6))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t7))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t8))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t9))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void fcitx::HybridInputContext::inputContextCreated(const QByteArray & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void fcitx::HybridInputContext::notifyFocusOut()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void fcitx::HybridInputContext::virtualKeyboardVisibilityChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
